@@ -1,7 +1,7 @@
 /* This file is part of the KDE project
 
    Copyright (C) 2005 Dario Massarin <nekkar@libero.it>
-   Copyright (C) 2007-2008 Lukas Appelhans <l.appelhans@gmx.de>
+   Copyright (C) 2007-2009 Lukas Appelhans <l.appelhans@gmx.de>
    Copyright (C) 2008 Urs Wolfer <uwolfer @ kde.org>
    Copyright (C) 2008 Dario Freddi <drf54321@gmail.com>
 
@@ -37,9 +37,12 @@
 #include <kiconloader.h>
 #include <kactioncollection.h>
 #include <kio/renamedialog.h>
+#ifndef HAVE_KNOTIFICATIONITEM
 #include <KSystemTrayIcon>
+#endif
 #include <KSharedConfig>
 #include <KPluginInfo>
+#include <KComboBox>
 
 #include <QTextStream>
 #include <QDomElement>
@@ -47,6 +50,10 @@
 #include <QClipboard>
 #include <QAbstractItemView>
 
+#ifdef HAVE_NEPOMUK
+    #include <Nepomuk/ResourceManager>
+#endif
+
 /**
  * This is our KGet class. This is where the user's transfers and searches are
  * stored and organized.
@@ -62,12 +69,27 @@ KGet& KGet::self( MainWindow * mainWindow )
     if(mainWindow)
     {
         m_mainWindow = mainWindow;
+        m_jobManager = new KUiServerJobs(m_mainWindow);
     }
 
     static KGet m;
     return m;
 }
 
+void KGet::deleteSelf()
+{
+    foreach (ModelObserver *observer, m_observers) {
+        KGet::delObserver(observer);
+    }
+    foreach (TransferGroup * group, m_transferTreeModel->transferGroups()) {
+        foreach (TransferGroupObserver *observer, group->handler()->m_observers) { //No we don't want to get stalked
+            group->handler()->delObserver(observer);
+        }
+
+        KGet::delGroup(group->name());
+    }
+}
+
 void KGet::addObserver(ModelObserver * observer)
 {
     kDebug(5001);
@@ -114,6 +136,12 @@ void KGet::delGroup(const QString& groupName)
 
     if(group)
     {
+        JobQueue::iterator begin = group->begin();
+        JobQueue::iterator end = group->end();
+        for (; begin != end; begin++) {
+            Transfer *transfer = static_cast<Transfer*>(*begin);
+            m_transferTreeModel->delTransfer(transfer);//Unregister transfers from model first, they will get deleted by the group when destructing
+        }
         m_transferTreeModel->delGroup(group);
         postRemovedTransferGroupEvent(group);
         delete(group);
@@ -141,12 +169,13 @@ QStringList KGet::transferGroupNames()
     return names;
 }
 
-void KGet::addTransfer(KUrl srcUrl, QString destDir, // krazy:exclude=passbyvalue
+void KGet::addTransfer(KUrl srcUrl, QString destDir, QString suggestedFileName, // krazy:exclude=passbyvalue
                        const QString& groupName, bool start)
 {
-    kDebug(5001) << "Source:" << srcUrl.url();
+    // Note: destDir may actually be a full path to a file :-(
+    kDebug() << "Source:" << srcUrl.url() << ", dest: " << destDir << ", sugg file: " << suggestedFileName << endl;
 
-    KUrl destUrl;
+    KUrl destUrl; // the final destination, including filename
 
     if ( srcUrl.isEmpty() )
     {
@@ -159,22 +188,55 @@ void KGet::addTransfer(KUrl srcUrl, QString destDir, // krazy:exclude=passbyvalu
     if ( !isValidSource( srcUrl ) )
         return;
 
+    // when we get a destination directory and suggested filename, we don't
+    // need to ask for it again
+    bool confirmDestination = false;
     if (destDir.isEmpty())
     {
-        if (Settings::useDefaultDirectory())
-            destDir = KUrl(Settings::defaultDirectory()).path();
-
-        QString checkExceptions = getSaveDirectoryFromExceptions(srcUrl);
-        if (Settings::enableExceptions() && !checkExceptions.isEmpty())
-            destDir = checkExceptions;
+        confirmDestination = true;
+        QList<TransferGroupHandler*> list = groupsFromExceptions(srcUrl);
+        if (!list.isEmpty())
+            destDir = list.first()->defaultFolder();
+    } else {
+        // check whether destDir is actually already the path to a file
+        KUrl targetUrl = KUrl(destDir);
+        QString directory = targetUrl.directory(KUrl::ObeyTrailingSlash);
+        QString fileName = targetUrl.fileName(KUrl::ObeyTrailingSlash);
+        if (QFileInfo(directory).isDir() && !fileName.isEmpty())
+        {
+            destDir = directory;
+            suggestedFileName = fileName;
+        }
     }
 
-    if (!isValidDestDirectory(destDir))
-        destDir = destInputDialog();
+    if (suggestedFileName.isEmpty())
+    {
+	confirmDestination = true;
+        suggestedFileName = srcUrl.fileName(KUrl::ObeyTrailingSlash);
+        if (suggestedFileName.isEmpty())
+        {
+            // simply use the full url as filename
+            suggestedFileName = KUrl::toPercentEncoding( srcUrl.prettyUrl(), "/" );
+        }
+    }
 
-    if( (destUrl = getValidDestUrl( destDir, srcUrl )).isEmpty() )
+    // now ask for confirmation of the entire destination url (dir + filename)
+    if (confirmDestination || !isValidDestDirectory(destDir))
+    {
+        do 
+        {
+            destUrl = destFileInputDialog(destDir, suggestedFileName);
+            if (destUrl.isEmpty()) 
         return;
 
+            destDir = destUrl.directory(KUrl::ObeyTrailingSlash);
+        } while (!isValidDestDirectory(destDir));
+    } else {
+        destUrl = KUrl();
+        destUrl.setDirectory(destDir); 
+        destUrl.addPath(suggestedFileName);
+    }
+
     if(m_transferTreeModel->findTransferByDestination(destUrl) != 0 || (destUrl.isLocalFile() && QFile::exists(destUrl.path()))) {
         KIO::RenameDialog dlg( m_mainWindow, i18n("Rename transfer"), srcUrl,
                                destUrl, KIO::M_MULTI);
@@ -231,8 +293,8 @@ void KGet::addTransfer(KUrl::List srcUrls, QString destDir, // krazy:exclude=pas
     KUrl destUrl;
 
     // multiple files -> ask for directory, not for every single filename
-    if (!isValidDestDirectory(destDir) && !Settings::useDefaultDirectory())
-        destDir = destInputDialog();
+    if (!isValidDestDirectory(destDir))//TODO: Move that after the for-loop
+        destDir = destDirInputDialog();
 
     it = urlsToDownload.begin();
     itEnd = urlsToDownload.end();
@@ -241,12 +303,9 @@ void KGet::addTransfer(KUrl::List srcUrls, QString destDir, // krazy:exclude=pas
     {
         if (destDir.isEmpty())
         {
-            if (Settings::useDefaultDirectory())
-                destDir = KUrl(Settings::defaultDirectory()).path();
-
-            QString checkExceptions = getSaveDirectoryFromExceptions(*it);
-            if (Settings::enableExceptions() && !checkExceptions.isEmpty())
-                destDir = checkExceptions;
+            QList<TransferGroupHandler*> list = groupsFromExceptions(*it);
+            if (!list.isEmpty())
+                destDir = list.first()->defaultFolder();
         }
         destUrl = getValidDestUrl(destDir, *it);
 
@@ -285,12 +344,13 @@ void KGet::redownloadTransfer(TransferHandler * transfer)
      QString group = transfer->group()->name();
      QString src = transfer->source().url();
      QString dest = transfer->dest().url();
+     QString destFile = transfer->dest().fileName();
      bool running = false;
      if (transfer->status() == Job::Running)
          running = true;
 
      KGet::delTransfer(transfer);
-     KGet::addTransfer(src, dest, group, running);
+     KGet::addTransfer(src, dest, destFile, group, running);
 }
 
 QList<TransferHandler *> KGet::selectedTransfers()
@@ -368,6 +428,11 @@ void KGet::addTransferView(QAbstractItemView * view)
     view->setModel(m_transferTreeModel);
 }
 
+void KGet::addTransferView(KComboBox * view)
+{
+    view->setModel(m_transferTreeModel);
+}
+
 void KGet::load( QString filename ) // krazy:exclude=passbyvalue
 {
     kDebug(5001) << "(" << filename << ")";
@@ -427,7 +492,7 @@ void KGet::load( QString filename ) // krazy:exclude=passbyvalue
         kWarning(5001) << "Error reading the transfers file";
     }
 
-    addObserver(new GenericModelObserver());
+    addObserver(new GenericModelObserver(m_mainWindow));
 }
 
 void KGet::save( QString filename, bool plain ) // krazy:exclude=passbyvalue
@@ -474,6 +539,7 @@ void KGet::save( QString filename, bool plain ) // krazy:exclude=passbyvalue
             QDomElement e = doc.createElement("TransferGroup");
             root.appendChild(e);
             (*it)->save(e);
+            //KGet::delGroup((*it)->name());
         }
 
         QTextStream stream( &file );
@@ -532,7 +598,12 @@ QList<TransferGroupHandler*> KGet::allTransferGroups()
 
 TransferHandler * KGet::findTransfer(const KUrl &src)
 {
-    return KGet::m_transferTreeModel->findTransfer(src)->handler();
+    Transfer *transfer = KGet::m_transferTreeModel->findTransfer(src);
+    if (transfer)
+    {
+        return transfer->handler();
+    }
+    return 0;
 }
 
 void KGet::checkSystemTray()
@@ -580,35 +651,22 @@ void KGet::reloadKJobs()
     m_jobManager->reload();
 }
 
-QStringList KGet::defaultFolders(const KUrl &filename, const QString &groupname)
+QList<TransferGroupHandler*> KGet::groupsFromExceptions(const KUrl &filename)
 {
-    kDebug(5001) << filename << groupname;
+    QList<TransferGroupHandler*> handlers;
+    foreach (TransferGroupHandler * handler, allTransferGroups()) {
+        QRegExp regExp = handler->regExp();
+        if (!regExp.pattern().isEmpty() && !regExp.pattern().startsWith('*'))
+            regExp.setPattern('*' + regExp.pattern());
 
-    QStringList list;
-    const QString saveDirectoryFromExceptions = KGet::getSaveDirectoryFromExceptions(filename);
-    if (Settings::enableExceptions() && !saveDirectoryFromExceptions.isEmpty())
-        list.append(saveDirectoryFromExceptions);
+        regExp.setPatternSyntax(QRegExp::Wildcard);
 
-    TransferGroup * group = KGet::m_transferTreeModel->findGroup(groupname);
-
-    if (!group->defaultFolder().isEmpty())
-        list.append(group->defaultFolder());
-
-    if (Settings::useDefaultDirectory())
-        list.append(Settings::defaultDirectory());
-
-    if (!Settings::lastDirectory().isEmpty() &&
-        QString::compare(Settings::lastDirectory(), Settings::defaultDirectory()) != 0)
-        list.append(Settings::lastDirectory());
-
-    if (list.isEmpty())
-        list.append(QDir::homePath());//If we have no defaultDir, we return the home-dir
-
-    for (int i = 0; i < list.size(); i++)
-    {
-        list[i] = KUrl(list[i]).path();
+        if (regExp.exactMatch(filename.url())) {
+            handlers.append(handler);
+        }
     }
-    return list;
+
+    return handlers;
 }
 
 void KGet::setGlobalDownloadLimit(int limit)
@@ -650,11 +708,15 @@ TransferTreeSelectionModel * KGet::m_selectionModel;
 QList<TransferFactory *> KGet::m_transferFactories;
 TransferGroupScheduler * KGet::m_scheduler = new TransferGroupScheduler();
 MainWindow * KGet::m_mainWindow = 0;
-KUiServerJobs * KGet::m_jobManager = new KUiServerJobs();
+KUiServerJobs * KGet::m_jobManager = 0;
 
 // ------ PRIVATE FUNCTIONS ------
 KGet::KGet()
 {
+#ifdef HAVE_NEPOMUK
+    Nepomuk::ResourceManager::instance()->init();
+#endif
+
     m_transferTreeModel = new TransferTreeModel(m_scheduler);
     m_selectionModel = new TransferTreeSelectionModel(m_transferTreeModel);
 
@@ -667,6 +729,7 @@ KGet::KGet()
 
 KGet::~KGet()
 {
+    delete m_transferTreeModel;
     delete m_scheduler;
 }
 
@@ -790,7 +853,7 @@ KUrl KGet::urlInputDialog()
     return KUrl();
 }
 
-QString KGet::destInputDialog()
+QString KGet::destDirInputDialog()
 {
     QString destDir = KFileDialog::getExistingDirectory(Settings::lastDirectory());
 
@@ -798,33 +861,32 @@ QString KGet::destInputDialog()
     return destDir;
 }
 
-QString KGet::getSaveDirectoryFromExceptions(const KUrl &filename)
+KUrl KGet::destFileInputDialog(QString destDir, const QString& suggestedFileName) // krazy:exclude=passbyvalue
 {
-    QString destDir;
+    if (destDir.isEmpty())
+        destDir = Settings::lastDirectory();
 
-    const QStringList list = Settings::extensionsFolderList();
-    QStringList::ConstIterator it = list.begin();
-    const QStringList::ConstIterator end = list.end();
-    while (it != end) {
-        // odd list items are regular expressions for extensions
-        QString ext = *it;
-        ++it;
-        QString path = *it;
-        ++it;
+    // open the filedialog for confirmation
+    KFileDialog dlg(destDir, QString(),
+                    0L, 0L);
+    dlg.setCaption(i18n("Save As"));
+    dlg.setOperationMode(KFileDialog::Saving);
+    dlg.setMode(KFile::File | KFile::LocalOnly);
 
-        if (!ext.startsWith('*'))
-            ext = '*' + ext;
+    // Use the destination name if not empty...
+    if (!suggestedFileName.isEmpty())
+        dlg.setSelection(suggestedFileName);
 
-        QRegExp rexp(ext);
-        rexp.setPatternSyntax(QRegExp::Wildcard);
-
-        if (rexp.exactMatch(filename.url())) {
-            destDir = path;
-            break;
-        }
+    if ( dlg.exec() == QDialog::Rejected )
+    {
+        return KUrl();
+    }
+    else
+    {
+        KUrl destUrl = dlg.selectedUrl();
+        Settings::setLastDirectory( destUrl.directory(KUrl::ObeyTrailingSlash) );
+        return destUrl;
     }
-
-    return KUrl(destDir).path();
 }
 
 bool KGet::isValidSource(const KUrl &source)
@@ -899,10 +961,10 @@ bool KGet::isValidDestUrl(const KUrl &destUrl)
 {
     if(KIO::NetAccess::exists(destUrl, KIO::NetAccess::DestinationSide, 0))
     {
-        if (KMessageBox::warningYesNoCancel(0,
+        if (KMessageBox::warningYesNo(0,
             i18n("Destination file \n%1\nalready exists.\n"
-                 "Do you want to overwrite it?", destUrl.prettyUrl()))
-            == KMessageBox::Yes)
+                 "Do you want to overwrite it?", destUrl.prettyUrl()), i18n("Overwrite destination"),
+            KStandardGuiItem::overwrite(), KStandardGuiItem::cancel()) == KMessageBox::Yes)
         {
             safeDeleteFile( destUrl );
             return true;
@@ -921,14 +983,14 @@ bool KGet::isValidDestUrl(const KUrl &destUrl)
    */
 }
 
-KUrl KGet::getValidDestUrl(const QString& destDir, const KUrl &srcUrl)
+KUrl KGet::getValidDestUrl(const QString& destDir, const KUrl &srcUrl, const QString& destFileName)
 {
     if ( !isValidDestDirectory(destDir) )
         return KUrl();
 
     // create a proper destination file from destDir
     KUrl destUrl = KUrl( destDir );
-    QString filename = srcUrl.fileName();
+    QString filename = destFileName.isEmpty() ? srcUrl.fileName() : destFileName;
 
     if ( filename.isEmpty() )
     {
@@ -964,14 +1026,13 @@ void KGet::loadPlugins()
     str += " and ";
     str += "[X-KDE-KGet-plugintype] == ";
 
-    KService::List offers;
 
     //TransferFactory plugins
-    offers = KServiceTypeTrader::self()->query( "KGet/Plugin", str + "'TransferFactory'" );
+    KService::List offers = KServiceTypeTrader::self()->query( "KGet/Plugin", str + "'TransferFactory'" );
 
     //Here we use a QMap only to easily sort the plugins by rank
     QMap<int, KService::Ptr> services;
-    QMap<int, KService::Ptr>::iterator it;
+    QMap<int, KService::Ptr>::ConstIterator it;
 
     for ( int i = 0; i < offers.count(); ++i )
     {
@@ -986,9 +1047,9 @@ void KGet::loadPlugins()
     //members of this class (why?), such as the m_transferFactories list.
     QList<KGetPlugin *> pluginList;
 
-    KConfigGroup plugins = KConfigGroup(KGlobal::config(), "Plugins");
-
-    for( it = services.begin(); it != services.end(); ++it )
+    const KConfigGroup plugins = KConfigGroup(KGlobal::config(), "Plugins");
+   
+    for( it = services.constBegin(); it != services.constEnd(); ++it )
     {
         KPluginInfo info(*it);
         info.load(plugins);
@@ -1002,7 +1063,7 @@ void KGet::loadPlugins()
         KGetPlugin * plugin;
         if( (plugin = createPluginFromService(*it)) != 0 )
         {
-            QString pluginName = info.name();
+            const QString pluginName = info.name();
             
             pluginList.prepend(plugin);
             kDebug(5001) << "TransferFactory plugin (" << (*it)->library() 
@@ -1014,8 +1075,8 @@ void KGet::loadPlugins()
                       << (*it)->library() << ")";
     }
 
-    QList<KGetPlugin *>::iterator it2 = pluginList.begin();
-    QList<KGetPlugin *>::iterator it2End = pluginList.end();
+    QList<KGetPlugin *>::ConstIterator it2 = pluginList.constBegin();
+    QList<KGetPlugin *>::ConstIterator it2End = pluginList.constEnd();
 
     for( ; it2!=it2End ; ++it2 )
         m_transferFactories.append( qobject_cast<TransferFactory *>(*it2) );
@@ -1071,7 +1132,7 @@ void KGet::showNotification(QWidget *parent, KNotification::StandardEvent eventI
 
 GenericModelObserver::GenericModelObserver(QObject *parent) : QObject(parent)
 {
-    m_groupObserver = new GenericTransferGroupObserver();
+    m_groupObserver = new GenericTransferGroupObserver(this);
 }
 
 GenericModelObserver::~GenericModelObserver()
