@@ -47,6 +47,7 @@ Transfer::Transfer(TransferGroup * parent, TransferFactory * factory,
     else
     {
         setStatus(status(), i18nc("transfer state: stopped", "Stopped"), SmallIcon("process-stop"));
+        setStartStatus(status());
     }
 }
 
@@ -56,6 +57,10 @@ Transfer::~Transfer()
         m_scheduler->stopDelayTimer(this);
 
     delete(m_handler);
+
+#ifdef HAVE_NEPOMUK
+    delete(m_nepomukHandler);
+#endif
 }
 
 int Transfer::elapsedTime() const
@@ -204,6 +209,7 @@ void Transfer::load(const QDomElement &e)
     {
         setStatus(status(), i18nc("transfer state: stopped", "Stopped"), SmallIcon("process-stop"));
     }
+    setStartStatus(status());
     setUploadLimit(e.attribute("UploadLimit").toInt(), Transfer::VisibleSpeedLimit);
     setDownloadLimit(e.attribute("DownloadLimit").toInt(), Transfer::VisibleSpeedLimit);
     m_runningSeconds = e.attribute("ElapsedTime").toInt();
@@ -237,7 +243,10 @@ void Transfer::setStatus(Job::Status jobStatus, const QString &text, const QPixm
 
 #ifdef HAVE_NEPOMUK
     if (jobStatus == Job::Finished)
+    {
+        m_nepomukHandler->addTags(group()->tags());
         m_nepomukHandler->saveFileProperties();
+    }
 #endif
 
     if (jobStatus == Job::Running && status() != Job::Running)
@@ -263,5 +272,8 @@ void Transfer::setStatus(Job::Status jobStatus, const QString &text, const QPixm
 
 void Transfer::setTransferChange(ChangesFlags change, bool postEvent)
 {
+    if (change & Tc_DownloadedSize || change & Tc_Status) {
+        change = change | Tc_RemainingTime;
+    }
     handler()->setTransferChange(change, postEvent);
 }
