@@ -22,10 +22,10 @@
 #include <KMenu>
 #include <QWidgetAction>
 
-#ifdef HAVE_KONQUEROR 
+#ifdef HAVE_KONQUEROR
     #include <KFileItem>
+    #include <kfileitemlistproperties.h>
     #include <konq_menuactions.h>
-    #include <konq_popupmenuinformation.h>
 #endif
 
 KMenu * ContextMenu::createTransferContextMenu(QList<TransferHandler*> transfers, QWidget *parent)
@@ -70,14 +70,17 @@ KMenu * ContextMenu::createTransferContextMenu(QList<TransferHandler*> transfers
     if (!actionList.isEmpty())
         popup->addSeparator();
 
-/*#ifdef HAVE_NEPOMUK //TODO: Reenable when Nepomuk is fixed
-    KMenu *nepomukMenu = new KMenu(i18n("Semantic desktop"), parent);
+#ifdef HAVE_NEPOMUK
+    KMenu *nepomukMenu = new KMenu(i18n("Semantic Desktop"), parent);
     nepomukMenu->setIcon(KIcon("nepomuk"));
-    QWidgetAction *nepomukWidget = new QWidgetAction(parent);
-    nepomukWidget->setDefaultWidget(new NepomukWidget(transfers.first(), parent));
-    nepomukMenu->addAction(nepomukWidget);
+    QWidgetAction *nepomukWidgetAction = new QWidgetAction(parent);
+    NepomukWidget *nepomukWidget = new NepomukWidget(transfers.first(), parent);
+    nepomukWidgetAction->setDefaultWidget(nepomukWidget);
+    nepomukMenu->addAction(nepomukWidgetAction);
+    nepomukMenu->setEnabled(nepomukWidget->isValid());
     popup->addMenu(nepomukMenu);
-#endif*/
+
+#endif
 
     popup->addAction( KGet::actionCollection()->action("transfer_open_dest") );
     //popup->addAction( KGet::actionCollection()->action("transfer_open_file") );
@@ -97,11 +100,9 @@ KMenu * ContextMenu::createTransferContextMenu(TransferHandler* handler, QWidget
         KFileItemList items;
         items << KFileItem(KFileItem::Unknown, KFileItem::Unknown, handler->dest());
 
-        KonqPopupMenuInformation popupInfo;
-        popupInfo.setItems(items);
-        popupInfo.setParentWidget(parent);
         KonqMenuActions menuActions;
-        menuActions.setPopupMenuInfo(popupInfo);
+//        menuActions.setItemListProperties(KFileItemListProperties(items));
+//        menuActions.setParentWidget(parent);
 
         menuActions.addActionsTo(popup);
         menuActions.addOpenWithActionsTo(popup, "DesktopEntryName != 'kget'");
@@ -129,9 +130,26 @@ KMenu * ContextMenu::createTransferGroupContextMenu(TransferGroupHandler *handle
     popup->addSeparator();
     popup->addAction(KGet::actionCollection()->action("transfer_group_settings"));
     popup->addSeparator();
-    if(handler->name() != i18n("My Downloads")) {
-        popup->addAction( KGet::actionCollection()->action("delete_groups") );
-        popup->addAction( KGet::actionCollection()->action("rename_groups") );
+
+    QList<TransferGroupHandler *> transferGroups = KGet::selectedTransferGroups();
+    bool containsMainGroup = false;
+    foreach(TransferGroupHandler *transHandler, transferGroups)
+    {
+        if(transHandler->name() == i18n("My Downloads"))
+        {
+            containsMainGroup = true;
+            break;
+        }
+    }
+    if(!containsMainGroup) {
+        const int numGroups = transferGroups.count();
+        QAction *action = KGet::actionCollection()->action("delete_groups");
+        action->setText(i18np("Delete Group", "Delete Groups", numGroups));
+        popup->addAction(action);
+
+        action = KGet::actionCollection()->action("rename_groups");
+        action->setText(i18np("Rename Group...", "Rename Groups...", numGroups));
+        popup->addAction(action);
     }
     popup->addAction( KGet::actionCollection()->action("seticon_groups") );
     return popup;
