@@ -8,11 +8,12 @@
    version 2 of the License, or (at your option) any later version.
 */
 
-#ifndef _TRANSFERSVIEW_H
-#define _TRANSFERSVIEW_H
+#ifndef TRANSFERSVIEW_H
+#define TRANSFERSVIEW_H
 
 #include <QTreeView>
 
+class KMenu;
 class TransferHandler;
 
 class TransfersView : public QTreeView
@@ -29,6 +30,7 @@ class TransfersView : public QTreeView
     private:
         void dropEvent(QDropEvent * event);
         void rowsInserted(const QModelIndex &, int, int);
+        void populateHeaderActions();
 
     protected:
         void dragMoveEvent ( QDragMoveEvent * event );
@@ -36,6 +38,11 @@ class TransfersView : public QTreeView
 
     private slots:
         void toggleMainGroup();// show or hide the first group header if there's only one download group
+        void slotSetColumnVisible(int column);
+        void slotShowHeaderMenu(const QPoint &point);
+
+    private:
+        KMenu *m_headerMenu;
 };
 
 #endif
