@@ -420,6 +420,11 @@ bool TransfersViewDelegate::editorEvent(QEvent * event, QAbstractItemModel * mod
             KMenu *popup = 0;
 
             TransferTreeModel * transferTreeModel = static_cast<TransferTreeModel *>(model);
+            QAbstractItemView * transferView = static_cast<QAbstractItemView *>(parent());
+
+            QItemSelection selectedRow(model->index(index.row(), 0, index.parent()),
+                                       model->index(index.row(), model->columnCount(), index.parent()));
+            transferView->selectionModel()->select(selectedRow, QItemSelectionModel::ClearAndSelect);
 
             if(transferTreeModel->isTransferGroup(index))
             {
@@ -488,7 +493,7 @@ void TransfersViewDelegate::closeExpandableDetails(const QModelIndex &transferIn
 
 QWidget *TransfersViewDelegate::getDetailsWidgetForTransfer(TransferHandler *handler)
 {
-    QGroupBox *groupBox = new QGroupBox(i18n("Transfer details"));
+    QGroupBox *groupBox = new QGroupBox(i18n("Transfer Details"));
 
     QVBoxLayout *layout = new QVBoxLayout(groupBox);
     QWidget *detailsWidget = TransferDetails::detailsWidget(handler);
@@ -505,7 +510,7 @@ QWidget *TransfersViewDelegate::getDetailsWidgetForTransfer(TransferHandler *han
     return groupBox;
 }
 
-void TransfersViewDelegate::itemActivated(QModelIndex index)
+void TransfersViewDelegate::itemActivated(const QModelIndex &index)
 {
     const TransferTreeModel * transferTreeModel = static_cast <const TransferTreeModel *> (index.model());
 
