@@ -95,6 +95,8 @@
 #include "kopetechatwindowstyle.h"
 #include "kopetechatwindowstylemanager.h"
 
+static const uint ConsecutiveMessageTimeout = 15 /* minutes */ * 60 /* (seconds/minute) */;
+
 class ToolTip;
 
 class ChatMessagePart::Private
@@ -105,7 +107,7 @@ public:
 	   copyAction(0), saveAction(0), printAction(0),
 	   closeAction(0),copyURLAction(0), currentChatStyle(0),
 	   latestDirection(Kopete::Message::Inbound), latestType(Kopete::Message::TypeNormal),
-	   htmlEventListener(0)
+	   latestTime(0), htmlEventListener(0)
 	{}
 
 	~Private()
@@ -136,6 +138,7 @@ public:
 	QPointer<Kopete::Contact> latestContact;
 	Kopete::Message::MessageDirection latestDirection;
 	Kopete::Message::MessageType latestType;
+	uint latestTime;
 	// Yep I know it will take memory, but I don't have choice
 	// to enable on-the-fly style changing.
 	QList<Kopete::Message> allMessages;
@@ -207,10 +210,9 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, QWidget *parent )
 {
 	d->manager = mgr;
 
-	d->currentChatStyle = ChatWindowStyleManager::self()->getStyleFromPool(
+	d->currentChatStyle = ChatWindowStyleManager::self()->getValidStyleFromPool(
 			 KopeteChatWindowSettings::self()->styleName() );
 
-	kDebug(14000) << d->currentChatStyle->getStyleName();
 	connect( this, SIGNAL(completed()), this, SLOT(slotRenderingFinished()) );
 
 	//Security settings, we don't need this stuff
@@ -252,7 +254,10 @@ ChatMessagePart::ChatMessagePart( Kopete::ChatSession *mgr, QWidget *parent )
 
 	connect( this, SIGNAL(popupMenu(const QString &, const QPoint &)),
 	         this, SLOT(slotRightClick(const QString &, const QPoint &)) );
-	connect( view()->verticalScrollBar(), SIGNAL(sliderMoved(int)),
+
+	// setup scrollbar
+	view()->verticalScrollBar()->setTracking(true);
+	connect( view()->verticalScrollBar(), SIGNAL(valueChanged(int)),
 	         this, SLOT(slotScrollingTo(int)) );
 
 	connect( Kopete::TransferManager::transferManager(), SIGNAL(askIncomingDone(unsigned int)),
@@ -364,7 +369,7 @@ void ChatMessagePart::slotOpenURLRequest(const KUrl &url, const KParts::OpenUrlA
 	kDebug(14000) << "url=" << url.url();
 	if ( url.protocol() == QLatin1String("kopetemessage") )
 	{
-		Kopete::Contact *contact = d->manager->account()->contacts()[ url.host() ];
+		Kopete::Contact *contact = d->manager->account()->contacts().value( url.host() );
 		if ( contact )
 			contact->execute();
 	}
@@ -401,7 +406,7 @@ void ChatMessagePart::readOverrides()
 void ChatMessagePart::setStyle( const QString &styleName )
 {
 	// Create a new ChatWindowStyle
-	d->currentChatStyle = ChatWindowStyleManager::self()->getStyleFromPool(styleName);
+	d->currentChatStyle = ChatWindowStyleManager::self()->getValidStyleFromPool(styleName);
 
 	// Do the actual style switch
 	// Wait for the event loop before switching the style
@@ -449,9 +454,16 @@ void ChatMessagePart::slotAppearanceChanged()
 
 void ChatMessagePart::appendMessage( Kopete::Message &message, bool restoring )
 {
-	message.setBackgroundOverride( d->bgOverride );
-	message.setForegroundOverride( d->fgOverride );
-	message.setRichTextOverride( d->rtfOverride );
+	if ( !d->currentChatStyle )
+		return;
+
+	// Don't remove foreground color for history messages.
+	if ( !message.classes().contains("history") )
+	{
+		message.setBackgroundOverride( d->bgOverride );
+		message.setForegroundOverride( d->fgOverride );
+		message.setRichTextOverride( d->rtfOverride );
+	}
 
 #ifdef STYLE_TIMETEST
 	QTime beforeMessage = QTime::currentTime();
@@ -480,6 +492,14 @@ void ChatMessagePart::appendMessage( Kopete::Message &message, bool restoring )
 		isConsecutiveMessage = (message.direction() == d->latestDirection && !d->latestContact.isNull()
 		                        && d->latestContact == message.from() && message.type() == d->latestType
 		                        && message.type() != Kopete::Message::TypeFileTransferRequest );
+
+		if(message.timestamp().isValid()){
+			uint next = message.timestamp().toTime_t();
+			if(isConsecutiveMessage && (next - d->latestTime) > ConsecutiveMessageTimeout){
+				isConsecutiveMessage = false;
+			}
+			d->latestTime = next;
+		}
 	}
 
 	// Don't test it in the switch to don't break consecutive messages.
@@ -915,6 +935,9 @@ void ChatMessagePart::emitTooltipEvent(  const QString &textUnderMouse, QString
 // Style formatting for messages(incoming, outgoing, status)
 QString ChatMessagePart::formatStyleKeywords( const QString &sourceHTML, const Kopete::Message &_message )
 {
+	if ( !d->currentChatStyle )
+		return QString();
+
 	Kopete::Message message=_message; //we will eventually need to modify it before showing it.
 	QString resultHTML = sourceHTML;
 	QString nick, contactId, service, protocolIcon, nickLink;
@@ -1155,7 +1178,7 @@ QString ChatMessagePart::formatTime(const QString &_timeFormat, const QDateTime
 	char buffer[256];
 #ifdef Q_WS_WIN
 	QString timeFormat = _timeFormat;
-	// %e is not supported on windows
+	// some formats are not supported on windows (gnu extension?)
 	timeFormat = timeFormat.replace(QLatin1String("%e"), QLatin1String("%d"));
 	timeFormat = timeFormat.replace(QLatin1String("%T"), QLatin1String("%H:%M:%S"));
 #else
@@ -1195,7 +1218,7 @@ QString ChatMessagePart::formatName( const Kopete::Contact* contact, Qt::TextFor
 		return QString();
 	}
 
-	// Use metacontact display name if the metacontact exists and if its not the myself metacontact.
+	// Use metacontact display name if the metacontact exists and if it is not the myself metacontact.
 	// Myself metacontact is not a reliable source.
 	if ( contact->metaContact() && contact->metaContact() != Kopete::ContactList::self()->myself() )
 	{
@@ -1281,37 +1304,44 @@ void ChatMessagePart::writeTemplate()
 	// baseStyle: Import the main.css from the Chat Window Style
 	// mainStyle: Currrent variant CSS url.
 
-	// FIXME: Maybe this string should be load from a file, then parsed for args.
 	QString xhtmlBase;
-	xhtmlBase += QString("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
-		"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"\n"
-		"\"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n"
-		"<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
-    	"<head>\n"
-        "<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\n\" />\n"
-        "<base href=\"%1\">\n"
-		"<style id=\"KopeteStyle\" type=\"text/css\" media=\"screen,print\">\n"
-		"	%5\n"
-		"</style>\n"
-		"<style id=\"baseStyle\" type=\"text/css\" media=\"screen,print\">\n"
-		"	@import url(\"main.css\");\n"
-		"	*{ word-wrap:break-word; }\n"
-		"</style>\n"
-		"<style id=\"mainStyle\" type=\"text/css\" media=\"screen,print\">\n"
-		"	@import url(\"%4\");\n"
-        "</style>\n"
-		"</head>\n"
-		"<body>\n"
-		"%2\n"
-		"<div id=\"Chat\">\n</div>\n"
-		"%3\n"
-		"</body>"
-		"</html>"
-		).arg( d->currentChatStyle->getStyleBaseHref() )
-		.arg( formatStyleKeywords(d->currentChatStyle->getHeaderHtml()) )
-		.arg( formatStyleKeywords(d->currentChatStyle->getFooterHtml()) )
-		.arg( adjustStyleVariantForChatSession( KopeteChatWindowSettings::self()->styleVariant() ) )
-		.arg( styleHTML() );
+	if ( d->currentChatStyle )
+	{
+		// FIXME: Maybe this string should be load from a file, then parsed for args.
+		xhtmlBase += QString("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n"
+			"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"\n"
+			"\"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n"
+			"<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
+			"<head>\n"
+			"<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\n\" />\n"
+			"<base href=\"%1\">\n"
+			"<style id=\"KopeteStyle\" type=\"text/css\" media=\"screen,print\">\n"
+			"	%5\n"
+			"</style>\n"
+			"<style id=\"baseStyle\" type=\"text/css\" media=\"screen,print\">\n"
+			"	@import url(\"main.css\");\n"
+			"	*{ word-wrap:break-word; }\n"
+			"</style>\n"
+			"<style id=\"mainStyle\" type=\"text/css\" media=\"screen,print\">\n"
+			"	@import url(\"%4\");\n"
+			"</style>\n"
+			"</head>\n"
+			"<body>\n"
+			"%2\n"
+			"<div id=\"Chat\">\n</div>\n"
+			"%3\n"
+			"</body>"
+			"</html>"
+			).arg( d->currentChatStyle->getStyleBaseHref() )
+			.arg( formatStyleKeywords(d->currentChatStyle->getHeaderHtml()) )
+			.arg( formatStyleKeywords(d->currentChatStyle->getFooterHtml()) )
+			.arg( adjustStyleVariantForChatSession( KopeteChatWindowSettings::self()->styleVariant() ) )
+			.arg( styleHTML() );
+	}
+	else
+	{
+		xhtmlBase = i18n( "Chat style could not be found, or is invalid." );
+	}
 	write(xhtmlBase);
 	end();
 #ifdef STYLE_TIMETEST
@@ -1358,7 +1388,7 @@ void ChatMessagePart::resendMessage( uint messageId )
 
 QString ChatMessagePart::adjustStyleVariantForChatSession( const QString & styleVariant ) const
 {
-	if ( d->manager->form() == Kopete::ChatSession::Chatroom
+	if ( d->currentChatStyle && d->manager->form() == Kopete::ChatSession::Chatroom
 			&& KopeteChatWindowSettings::self()->useCompact() ) {
 		return d->currentChatStyle->compact( styleVariant );
 	}
@@ -1415,6 +1445,9 @@ void ChatMessagePart::disableFileTransferButtons( unsigned int id )
 
 void ChatMessagePart::changeMessageStateElement( uint id, Kopete::Message::MessageState state )
 {
+	if ( !d->currentChatStyle )
+		return;
+
 	QString elementId = QString( "msST%1" ).arg( id );
 	DOM::HTMLElement element = document().getElementById( elementId );
 	if ( element.isNull() )
