@@ -59,6 +59,7 @@
 #include <kopetechatwindowstylemanager.h>
 #include <kopetechatwindowstyle.h>
 #include <chatmessagepart.h>
+#include <kopetecontactlist.h>
 
 
 // Things we fake to get the message preview to work
@@ -143,7 +144,7 @@ private:
 ChatWindowConfig::ChatWindowConfig(QWidget *parent, const QVariantList &args )
 	: KCModule( KopeteChatWindowConfigFactory::componentData(), parent, args ),
 		m_currentStyle (0L), m_loading(false),
-		m_previewProtocol(0L), m_previewAccount(0L), m_myselfMetaContact(0L),
+		m_previewProtocol(0L), m_previewAccount(0L),
 		m_jackMetaContact(0L), m_myself(0L), m_jack(0L)
 {
 	KConfigGroup config(KGlobal::config(), "ChatWindowSettings");
@@ -232,7 +233,6 @@ ChatWindowConfig::~ChatWindowConfig()
 	// Deleting the account will delete jack and myself
 	delete m_previewAccount;
 
-	delete m_myselfMetaContact;
 	delete m_jackMetaContact;
 
  	delete m_previewProtocol;
@@ -368,6 +368,10 @@ void ChatWindowConfig::slotChatStyleSelected(const QString &styleName)
 
 		emitChanged();
 	}
+	else {
+		m_styleUi.variantList->clear();
+		slotUpdateChatPreview();
+	}
 }
 
 void ChatWindowConfig::slotChatStyleVariantSelected(const QString &variantName)
@@ -379,6 +383,9 @@ void ChatWindowConfig::slotChatStyleVariantSelected(const QString &variantName)
 	// form
 	QString styleName = m_styleUi.styleList->currentItem()->text();
 	m_currentStyle = ChatWindowStyleManager::self()->getStyleFromPool( styleName );
+	if ( !m_currentStyle )
+		return;
+
 	if ( m_styleUi.variantList->currentIndex() == 0 ) {
 		m_styleUi.kcfg_useCompact->setEnabled(m_currentStyle->hasCompact( "" ) );
 	}
@@ -392,7 +399,7 @@ void ChatWindowConfig::slotChatStyleVariantSelected(const QString &variantName)
 
 void ChatWindowConfig::slotInstallChatStyle()
 {
-	KUrl styleUrl = KFileDialog::getOpenUrl( KUrl(), QString::fromUtf8("application/zip application/x-compressed-tar application/x-bzip-compressed-tar"), this, i18n("Choose a Chat Window Style to install") );
+	KUrl styleUrl = KFileDialog::getOpenUrl( KUrl(), QString::fromUtf8("application/zip application/x-compressed-tar application/x-bzip-compressed-tar"), this, i18n("Choose Chat Window Style to Install") );
 
 	if ( styleUrl.isEmpty() ) // dialog got canceled
 		return;
@@ -403,26 +410,26 @@ void ChatWindowConfig::slotInstallChatStyle()
 	{
 		case ChatWindowStyleManager::StyleCannotOpen:
 		{
-			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("The specified archive cannot be opened.\nMake sure that the archive is a valid ZIP or TAR archive."), i18n("Cannot open archive") );
+			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("The specified archive cannot be opened.\nMake sure that the archive is a valid ZIP or TAR archive."), i18n("Cannot Open Archive") );
 			break;
 		}
 		case ChatWindowStyleManager::StyleNoDirectoryValid:
 		{
-			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("Could not find a suitable place to install the Chat Window Style."), i18n("Cannot find styles directory") );
+			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("Could not find a suitable place to install the chat window style."), i18n("Cannot Find Styles Directory") );
 			break;
 		}
 		case ChatWindowStyleManager::StyleNotValid:
-			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("The specified archive does not contain a valid Chat Window Style."), i18n("Invalid Style") );
+			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("The specified archive does not contain a valid chat window style."), i18n("Invalid Style") );
 			break;
 		case ChatWindowStyleManager::StyleInstallOk:
 		{
-			KMessageBox::queuedMessageBox( this, KMessageBox::Information, i18n("The Chat Window Style was successfully installed."), i18n("Install successful") );
+			KMessageBox::queuedMessageBox( this, KMessageBox::Information, i18n("The chat window style was successfully installed."), i18n("Install Successful") );
 			break;
 		}
 		case ChatWindowStyleManager::StyleUnknow:
 		default:
 		{
-			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("An unknown error occurred while trying to install the Chat Window Style."), i18n("Unknown error") );
+			KMessageBox::queuedMessageBox( this, KMessageBox::Error, i18n("An unknown error occurred while trying to install the chat window style."), i18n("Unknown Error") );
 			break;
 		}
 	}
@@ -539,13 +546,7 @@ void ChatWindowConfig::createPreviewChatSession()
 	m_previewProtocol = new FakeProtocol( KComponentData(QByteArray("kopete-preview-chatwindowstyle")), 0 ); m_previewProtocol->setObjectName( QLatin1String("kopete-preview-chatwindowstyle") );
 	m_previewAccount = new FakeAccount(m_previewProtocol, QString("previewaccount"));
 
-	// Create fake meta/contacts
-	m_myselfMetaContact = new Kopete::MetaContact();
-	m_myselfMetaContact->setTemporary();
-	m_myselfMetaContact->setDisplayName(i18n("Myself"));
-	m_myselfMetaContact->setDisplayNameSource(Kopete::MetaContact::SourceCustom);
-
-	m_myself = new FakeContact(m_previewAccount, i18nc("This is the myself preview contact id", "myself@preview"), m_myselfMetaContact);
+	m_myself = new FakeContact(m_previewAccount, i18nc("This is the myself preview contact id", "myself@preview"), Kopete::ContactList::self()->myself());
 	m_myself->setNickName(i18nc("This is the myself preview contact nickname", "Myself"));
 
 	m_jackMetaContact = new Kopete::MetaContact();
@@ -594,7 +595,7 @@ void ChatWindowConfig::createPreviewMessages()
 	msgOut4.setState( Kopete::Message::StateSent );
 
 	Kopete::Message msgOut5( m_myself, m_jack );
-	msgOut5.setPlainBody( i18n( "Message that can't be delivered." ) );
+	msgOut5.setPlainBody( i18n( "Message that cannot be delivered." ) );
 	msgOut5.setDirection( Kopete::Message::Outbound );
 	msgOut5.setState( Kopete::Message::StateError );
 
@@ -662,7 +663,7 @@ void ChatWindowConfig::createPreviewMessages()
 
 void ChatWindowConfig::slotUpdateChatPreview()
 {
-	if(m_loading || !m_currentStyle)
+	if(m_loading)
 		return;
 
 	// Update the preview
