@@ -882,15 +882,19 @@ void VideoDevicePool::deviceRemoved( const QString & udi )
 {
 	kDebug() << "("<< udi << ") called";
 	int i = 0;
-	foreach ( VideoDevice vd, m_videodevice ) {
-		
-		if ( vd.udi() == udi ) {
+	foreach ( VideoDevice vd, m_videodevice )
+	{
+		if ( vd.udi() == udi )
+		{
 			kDebug() << "Video device '" << udi << "' has been removed!";
+			emit deviceUnregistered( udi );
+			// not sure if this is safe but at this point the device node is gone already anyway
+			m_videodevice.remove( i );
+		}
+		else
+		{
+			i++;
 		}
-		emit deviceUnregistered( udi );
-		m_videodevice.remove( i ); // not sure if this is safe but at this point the device node is
-								   // gone already anyway
-		i++;
 	}
 }
 
