@@ -112,7 +112,6 @@ Account::Account( Protocol *parent, const QString &accountId )
 
 Account::~Account()
 {
-	d->contacts.remove( d->myself->contactId() );
 	// Delete all registered child contacts first
 	foreach (Contact* c, d->contacts) QObject::disconnect(c, SIGNAL( contactDestroyed( Kopete::Contact * ) ), this, 0);
 	qDeleteAll(d->contacts);
@@ -242,17 +241,21 @@ bool Account::excludeConnect() const
 	return d->excludeconnect;
 }
 
-void Account::registerContact( Contact *c )
+bool Account::registerContact( Contact *c )
 {
-	if ( d->contacts.value( c->contactId(), 0 ) )
+	Q_ASSERT ( c->metaContact() != Kopete::ContactList::self()->myself() );
+
+	if ( d->contacts.value( c->contactId() ) )
 	{
 		kWarning(14010) << "Contact already exists!!! accountId: " << c->account() << " contactId: " << c->contactId();
-		return;
+		return false;
 	}
 
 	d->contacts.insert( c->contactId(), c );
 	QObject::connect( c, SIGNAL( contactDestroyed( Kopete::Contact * ) ),
 		SLOT( contactDestroyed( Kopete::Contact * ) ) );
+
+	return true;
 }
 
 void Account::contactDestroyed( Contact *c )
@@ -270,7 +273,7 @@ const QHash<QString, Contact*>& Account::contacts()
 Kopete::MetaContact* Account::addContact( const QString &contactId, const QString &displayName , Group *group, AddMode mode  )
 {
 
-	if ( contactId == d->myself->contactId() )
+	if ( !protocol()->canAddMyself() && contactId == d->myself->contactId() )
 	{
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
 			i18n("You are not allowed to add yourself to the contact list. The addition of \"%1\" to account \"%2\" will not take place.", contactId, accountId()), i18n("Error Creating Contact")
@@ -278,9 +281,9 @@ Kopete::MetaContact* Account::addContact( const QString &contactId, const QStrin
 		return false;
 	}
 
-	bool isTemporary = mode == Temporary;
+	bool isTemporary = (mode == Temporary);
 
-	Contact *c = d->contacts[ contactId ];
+	Contact *c = d->contacts.value( contactId );
 
 	if(!group)
 		group=Group::topLevel();
@@ -336,7 +339,7 @@ Kopete::MetaContact* Account::addContact( const QString &contactId, const QStrin
 
 bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode mode )
 {
-	if ( contactId == myself()->contactId() )
+	if ( !protocol()->canAddMyself() && contactId == myself()->contactId() )
 	{
 	    	KMessageBox::error( Kopete::UI::Global::mainWidget(),
 			i18n("You are not allowed to add yourself to the contact list. The addition of \"%1\" to account \"%2\" will not take place.", contactId, accountId()), i18n("Error Creating Contact")
@@ -344,8 +347,8 @@ bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode
 		return 0L;
 	}
 
-	bool isTemporary= parent->isTemporary();
-	Contact *c = d->contacts[ contactId ];
+	const bool isTemporary= parent->isTemporary();
+	Contact *c = d->contacts.value( contactId );
 	if ( c && c->metaContact() )
 	{
 		if ( c->metaContact()->isTemporary() && !isTemporary )
@@ -365,7 +368,7 @@ bool Account::addContact(const QString &contactId , MetaContact *parent, AddMode
 		return false; //(the contact is not in the correct metacontact, so false)
 	}
 
-	bool success = createContact(contactId, parent);
+	const bool success = createContact(contactId, parent);
 
 	if ( success && mode == ChangeKABC )
 	{
@@ -447,36 +450,24 @@ Contact * Account::myself() const
 
 void Account::setMyself( Contact *myself )
 {
-	//FIXME  does it make sens to change the myself contact to another ?   - Olivier 2005-11-21
-
-	bool wasConnected = isConnected();
-
-	if ( d->myself )
-	{
-		QObject::disconnect( d->myself, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
-			this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
-		QObject::disconnect( d->myself, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
-			this, SLOT( slotContactPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) );
-	}
+	Q_ASSERT( !d->myself );
 
 	d->myself = myself;
 
-//	d->contacts.remove( myself->contactId() );
-
 	QObject::connect( d->myself, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
 		this, SLOT( slotOnlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 	QObject::connect( d->myself, SIGNAL( propertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ),
 		this, SLOT( slotContactPropertyChanged( Kopete::PropertyContainer *, const QString &, const QVariant &, const QVariant & ) ) );
 
-	if ( isConnected() != wasConnected )
+	if ( isConnected() )
 		emit isConnectedChanged();
 }
 
 void Account::slotOnlineStatusChanged( Contact * /* contact */,
 	const OnlineStatus &newStatus, const OnlineStatus &oldStatus )
 {
-	bool wasOffline = !oldStatus.isDefinitelyOnline();
-	bool isOffline  = !newStatus.isDefinitelyOnline();
+	const bool wasOffline = !oldStatus.isDefinitelyOnline();
+	const bool isOffline  = !newStatus.isDefinitelyOnline();
 
 	if ( wasOffline || newStatus.status() == OnlineStatus::Offline )
 	{
@@ -495,8 +486,8 @@ void Account::slotOnlineStatusChanged( Contact * /* contact */,
 	if ( !isOffline )
 	{
 		d->restoreStatus = newStatus;
-		d->restoreMessage.setTitle( identity()->property( Kopete::Global::Properties::self()->statusTitle() ).value().toString() );
-		d->restoreMessage.setMessage( identity()->property( Kopete::Global::Properties::self()->statusMessage() ).value().toString() );
+		d->restoreMessage.setTitle( myself()->property( Kopete::Global::Properties::self()->statusTitle() ).value().toString() );
+		d->restoreMessage.setMessage( myself()->property( Kopete::Global::Properties::self()->statusMessage() ).value().toString() );
 	}
 
 /*	kDebug(14010) << "account " << d->id << " changed status. was "
@@ -517,7 +508,7 @@ void Account::setAllContactsStatus( const Kopete::OnlineStatus &status )
 		it.next();
 
 		Contact *c = it.value();
-		if ( c && c != d->myself )
+		if ( c )
 			c->setOnlineStatus( status );
 	}
 }
@@ -578,8 +569,10 @@ void Account::editAccount(QWidget *parent)
 
 	KopeteEditAccountWidget *m_accountWidget = protocol()->createEditAccountWidget( this, editDialog );
 	if ( !m_accountWidget )
+	{
+		delete editDialog;
 		return;
-
+	}
 	// FIXME: Why the #### is EditAccountWidget not a QWidget?!? This sideways casting
 	//        is braindead and error-prone. Looking at MSN the only reason I can see is
 	//        because it allows direct subclassing of designer widgets. But what is
@@ -588,8 +581,10 @@ void Account::editAccount(QWidget *parent)
 	//        class should at least be renamed to EditAccountIface instead - Martijn
 	QWidget *w = dynamic_cast<QWidget *>( m_accountWidget );
 	if ( !w )
+	{
+		delete editDialog;
 		return;
-
+	}
 	editDialog->setMainWidget( w );
 	if ( editDialog->exec() == QDialog::Accepted )
 	{
