@@ -25,6 +25,7 @@
 #include <QtCore/QStringList>
 #include <QtCore/QDir>
 #include <QtGui/QPainter>
+#include <QtGui/QImageReader>
 
 // KDE includes
 #include <kdebug.h>
@@ -38,6 +39,7 @@
 
 // Kopete includes
 #include <kopetecontact.h>
+#include <kopeteprotocol.h>
 #include <kopeteaccount.h>
 
 namespace Kopete
@@ -113,6 +115,9 @@ Kopete::AvatarManager::AvatarEntry AvatarManager::add(Kopete::AvatarManager::Ava
 			if( newEntry.contact && newEntry.contact->account() )
 			{
 				QString accountName = newEntry.contact->account()->accountId();
+				QString protocolName = newEntry.contact->account()->protocol()->pluginId();                                
+				avatarUrl.addPath( protocolName );
+				d->createDirectory( avatarUrl );
 				avatarUrl.addPath( accountName );
 				d->createDirectory( avatarUrl );
 			}
@@ -121,20 +126,48 @@ Kopete::AvatarManager::AvatarEntry AvatarManager::add(Kopete::AvatarManager::Ava
 			break;
 	}
 
+	KUrl dataUrl(avatarUrl);
+
 	kDebug(14010) << "Base directory: " << avatarUrl.path();
 
 	// Second, open the avatar configuration in current directory.
 	KUrl configUrl = avatarUrl;
 	configUrl.addPath( AvatarConfig );
 	
-	QImage avatar;
-	if( !newEntry.path.isEmpty() && newEntry.image.isNull() )
+	QByteArray data = newEntry.data;
+	QImage avatar = newEntry.image;
+
+	if (!data.isNull())
 	{
+		avatar.loadFromData(data);
+	}
+	else if(!newEntry.dataPath.isEmpty()){
+		QFile f(newEntry.dataPath);
+		f.open(QIODevice::ReadOnly);
+		data = f.readAll();
+		f.close();
+
+		avatar.loadFromData(data);
+	}
+	else if(!avatar.isNull()){
+		QByteArray tempArray;
+		QBuffer tempBuffer(&tempArray);
+		tempBuffer.open( QIODevice::WriteOnly );
+		avatar.save(&tempBuffer, "PNG");
+
+		data = tempArray;
+	}
+	else if(!newEntry.path.isEmpty()){
 		avatar = QImage(newEntry.path);
+
+		QFile f(newEntry.path);
+		f.open(QIODevice::ReadOnly);
+		data = f.readAll();
+		f.close();
 	}
 	else
 	{
-		avatar = newEntry.image;
+		kDebug() << "Warning: No valid image source!";
 	}
 
 	// Scale avatar
@@ -169,22 +202,49 @@ Kopete::AvatarManager::AvatarEntry AvatarManager::add(Kopete::AvatarManager::Ava
 		kDebug(14010) << "Saving of " << avatarUrl.path() << " failed !";
 		return AvatarEntry();
 	}
-	else
+
+	QString dataFilename;
+
+	// for the contact avatar, save it with the contactId + .png
+	if (newEntry.category == AvatarManager::Contact && newEntry.contact)
 	{
-		// Save metadata of image
-		KConfigGroup avatarConfig(KSharedConfig::openConfig( configUrl.path(), KConfig::SimpleConfig), newEntry.name );
-	
-		avatarConfig.writeEntry( "Filename", avatarFilename );
-		avatarConfig.writeEntry( "Category", int(newEntry.category) );
-
-		avatarConfig.sync();
-	
-		// Add final path to the new entry for avatarAdded signal
-		newEntry.path = avatarUrl.path();
-
-		emit avatarAdded(newEntry);
+		dataFilename = newEntry.contact->contactId() + QLatin1String("_");
 	}
 
+	dataFilename += KMD5(data).hexDigest();
+
+	QBuffer buffer(&data);
+	buffer.open(QIODevice::ReadOnly);
+	QImageReader ir(&buffer);
+	dataFilename += QLatin1String(".") + QLatin1String(ir.format());
+
+	// Save (original) data on disk
+	dataUrl.addPath(dataFilename);
+	QFile f(dataUrl.path());
+	if (!f.open(QIODevice::WriteOnly))
+	{
+		kDebug(14010) << "Saving of " << dataUrl.path() << " failed !";
+		return AvatarEntry();
+	}
+	f.write(data);
+	f.flush();
+	f.close();
+
+	// Save metadata of image
+	KConfigGroup avatarConfig(KSharedConfig::openConfig( configUrl.path(), KConfig::SimpleConfig), newEntry.name );
+	
+	avatarConfig.writeEntry( "Filename", avatarFilename );
+	avatarConfig.writeEntry( "DataFilename", dataFilename );
+	avatarConfig.writeEntry( "Category", int(newEntry.category) );
+
+	avatarConfig.sync();
+	
+	// Add final path to the new entry for avatarAdded signal
+	newEntry.path = avatarUrl.path();
+	newEntry.dataPath = dataUrl.path();
+
+	emit avatarAdded(newEntry);
+
 	return newEntry;
 }
 
@@ -248,7 +308,7 @@ QImage AvatarManager::Private::scaleImage(const QImage &source)
 	// scale and center the image
 	if( source.width() > 96 || source.height() > 96 )
 	{
-		QImage scaled = source.scaled( 96, 96, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+		const QImage scaled = source.scaled( 96, 96, Qt::KeepAspectRatio, Qt::SmoothTransformation );
 
 		x = (96 - scaled.width()) / 2.0;
 		y = (96 - scaled.height()) / 2.0;
@@ -313,8 +373,8 @@ void AvatarQueryJob::start()
 		KUrl contactUrl(d->baseDir);
 		contactUrl.addPath( ContactDir );
 
-		QDir contactDir(contactUrl.path());
-		QStringList subdirsList = contactDir.entryList( QDir::AllDirs | QDir::NoDotAndDotDot );
+		const QDir contactDir(contactUrl.path());
+		const QStringList subdirsList = contactDir.entryList( QDir::AllDirs | QDir::NoDotAndDotDot );
 		foreach(const QString &subdir, subdirsList)
 		{
 			d->listAvatarDirectory( ContactDir + QDir::separator() + subdir );
@@ -344,7 +404,7 @@ void AvatarQueryJob::Private::listAvatarDirectory(const QString &relativeDirecto
 	{
 		KConfig *avatarConfig = new KConfig( avatarConfigUrl.path(), KConfig::SimpleConfig);
 		// Each avatar entry in configuration is a group
-		QStringList groupEntryList = avatarConfig->groupList();
+		const QStringList groupEntryList = avatarConfig->groupList();
 		foreach(const QString &groupEntry, groupEntryList)
 		{
 			KConfigGroup cg(avatarConfig, groupEntry);
@@ -353,11 +413,16 @@ void AvatarQueryJob::Private::listAvatarDirectory(const QString &relativeDirecto
 			listedEntry.name = groupEntry;
 			listedEntry.category = static_cast<Kopete::AvatarManager::AvatarCategory>( cg.readEntry("Category", 0) );
 
-			QString filename = cg.readEntry( "Filename", QString() );
+			const QString filename = cg.readEntry( "Filename", QString() );
 			KUrl avatarPath(avatarDirectory);
 			avatarPath.addPath( filename );
 			listedEntry.path = avatarPath.path();
 
+			const QString dataFilename = cg.readEntry( "DataFilename", QString() );
+			KUrl dataPath(avatarDirectory);
+			dataPath.addPath( dataFilename );
+			listedEntry.dataPath = dataPath.path();
+
 			avatarList << listedEntry;
 		}
                 delete avatarConfig;
