@@ -85,10 +85,8 @@ public:
 
 Contact::Contact( Account *account, const QString &contactId,
 	MetaContact *parent, const QString &icon )
-	: ContactListElement( parent )
+	: ContactListElement( parent ), d(new Private())
 {
-	d = new Private;
-
 	//kDebug( 14010 ) << "Creating contact with id " << contactId;
 
 	d->contactId = contactId;
@@ -98,24 +96,26 @@ Contact::Contact( Account *account, const QString &contactId,
 	d->idleTime = 0;
 	d->icon = icon;
 
+	bool duplicate = false;
 	// If can happend that a MetaContact may be used without a account
 	// (ex: for unit tests or chat window style preview)
 	if ( account )
 	{
-		account->registerContact( this );
+		// Don't register myself contacts because otherwise we can't have own contact in contact list.
+		if ( d->metaContact != Kopete::ContactList::self()->myself() )
+			duplicate = !account->registerContact( this );
+
 		connect( account, SIGNAL( isConnectedChanged() ), SLOT( slotAccountIsConnectedChanged() ) );
 	}
 
 	// Need to check this because myself() may have no parent
 	// Maybe too the metaContact doesn't have a valid protocol()
 	// (ex: for unit tests or chat window style preview)
-	if( parent && protocol() )
-	{
-		connect( parent, SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
-			protocol(), SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
 
+	// if alreadyRegistered is true (which mean that this is duplicate contact) we will not add
+	// parent and the contact will die out on next Kopete restart.
+	if( !duplicate && parent && protocol() )
 		parent->addContact( this );
-	}
 }
 
 Contact::~Contact()
@@ -140,6 +140,7 @@ void Contact::setOnlineStatus( const OnlineStatus &status )
 	if( status == d->onlineStatus )
 		return;
 
+	const bool oldCanAcceptFiles = canAcceptFiles();
 	OnlineStatus oldStatus = d->onlineStatus;
 	d->onlineStatus = status;
 
@@ -166,6 +167,9 @@ void Contact::setOnlineStatus( const OnlineStatus &status )
 
 	if ( this == account()->myself() || account()->isConnected() )
 		emit onlineStatusChanged( this, status, oldStatus );
+
+	if ( oldCanAcceptFiles != canAcceptFiles() )
+		emit canAcceptFilesChanged();
 }
 
 Kopete::StatusMessage Contact::statusMessage() const
@@ -223,7 +227,7 @@ KMenu* Contact::popupMenu( ChatSession *manager )
 	KMenu *menu = new KMenu();
 
 	QString titleText;
-	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
+	const QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
 	if( nick.isEmpty() )
 		titleText = QString::fromLatin1( "%1 (%2)" ).arg( contactId(), onlineStatus().description() );
 	else
@@ -240,18 +244,18 @@ KMenu* Contact::popupMenu( ChatSession *manager )
 	}
 
 	// FIXME: After KDE 3.2 we should make isReachable do the isConnected call so it can be removed here - Martijn
-	bool reach = account()->isConnected() && isReachable();
-	bool myself = (this == account()->myself());
+	const bool reach = account()->isConnected() && isReachable();
+	const bool myself = (this == account()->myself());
 
-	KAction *actionSendMessage = KopeteStdAction::sendMessage( this, SLOT( sendMessage() ), 0, "actionSendMessage" );
+	KAction *actionSendMessage = KopeteStdAction::sendMessage( this, SLOT( sendMessage() ), menu );
 	actionSendMessage->setEnabled( reach && !myself );
 	menu->addAction( actionSendMessage );
 
-	KAction *actionChat = KopeteStdAction::chat( this, SLOT( startChat() ), 0, "actionChat" );
+	KAction *actionChat = KopeteStdAction::chat( this, SLOT( startChat() ), menu );
 	actionChat->setEnabled( reach && !myself );
 	menu->addAction( actionChat );
 
-	KAction *actionSendFile = KopeteStdAction::sendFile( this, SLOT( sendFile() ), 0, "actionSendFile" );
+	KAction *actionSendFile = KopeteStdAction::sendFile( this, SLOT( sendFile() ), menu );
 	actionSendFile->setEnabled( reach && d->fileCapable && !myself );
 	menu->addAction( actionSendFile );
 
@@ -273,11 +277,11 @@ KMenu* Contact::popupMenu( ChatSession *manager )
 
 	if( metaContact() && !metaContact()->isTemporary() )
 	{
-		KAction* changeMetaContact = KopeteStdAction::changeMetaContact( this, SLOT( changeMetaContact() ), 0, "actionChangeMetaContact" );
+		KAction* changeMetaContact = KopeteStdAction::changeMetaContact( this, SLOT( changeMetaContact() ), menu );
 		menu->addAction( changeMetaContact );
 	}
 
-	menu->addAction( KopeteStdAction::contactInfo( this, SLOT( slotUserInfo() ), 0, "actionUserInfo" ) );
+	menu->addAction( KopeteStdAction::contactInfo( this, SLOT( slotUserInfo() ), menu ) );
 
 #if 0 //this is not fully implemented yet (and doesn't work).  disable for now   - Olivier 2005-01-11
 	if ( account()->isBlocked( d->contactId ) )
@@ -287,7 +291,7 @@ KMenu* Contact::popupMenu( ChatSession *manager )
 #endif
 
 	if( metaContact() && !metaContact()->isTemporary() )
-		menu->addAction( KopeteStdAction::deleteContact( this, SLOT( slotDelete() ), 0, "actionDeleteContact" ) );
+		menu->addAction( KopeteStdAction::deleteContact( this, SLOT( slotDelete() ), menu ) );
 
 	return menu;
 }
@@ -318,6 +322,13 @@ void Contact::changeMetaContact()
 		if(chkCreateNew->isChecked())
 		{
 			mc=new Kopete::MetaContact();
+
+			if ( metaContact() )
+			{	// Add new metaContact to old groups so we don't move it to Top Level group
+				foreach ( Kopete::Group* group, metaContact()->groups() )
+					mc->addToGroup( group );
+			}
+
 			Kopete::ContactList::self()->addMetaContact(mc);
 		}
 		if( mc )
@@ -338,8 +349,6 @@ void Contact::setMetaContact( MetaContact *m )
 	if( old )
 	{
 		old->removeContact( this );
-		disconnect( old, SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
-			protocol(), SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
 
 		if(old->contacts().isEmpty())
 		{
@@ -350,7 +359,7 @@ void Contact::setMetaContact( MetaContact *m )
 		{
 			d->metaContact = m; //i am forced to do that now if i want the next line works
 			//remove cached data for this protocol which will not be removed since we disconnected
-			protocol()->slotMetaContactAboutToSave( old );
+			protocol()->serialize( old );
 		}
 	}
 
@@ -364,8 +373,6 @@ void Contact::setMetaContact( MetaContact *m )
 		// between adding completely new contacts (which should be written to kabc) and restoring upon restart
 		// (where no write is needed).
 		KABCPersistence::self()->write( m );
-		connect( d->metaContact, SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
-		protocol(), SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
 	}
 	sync();
 }
@@ -495,10 +502,13 @@ bool Contact::isFileCapable() const
 
 void Contact::setFileCapable( bool filecap )
 {
-	d->fileCapable = filecap;
+	if ( d->fileCapable != filecap )
+	{
+		d->fileCapable = filecap;
+		emit canAcceptFilesChanged();
+	}
 }
 
-
 bool Contact::canAcceptFiles() const
 {
 	return isOnline() && d->fileCapable;
@@ -531,7 +541,7 @@ QString Contact::toolTip() const
 {
 	Kopete::Property p;
 	QString tip;
-	QStringList shownProps = Kopete::AppearanceSettings::self()->toolTipContents();
+	const QStringList shownProps = Kopete::AppearanceSettings::self()->toolTipContents();
 
 	// --------------------------------------------------------------------------
 	// Fixed part of tooltip
@@ -574,20 +584,20 @@ QString Contact::toolTip() const
 	// Configurable part of tooltip
 
 	// FIXME: It shouldn't use QString to identity the properties. Instead it should use PropertyTmpl::key()
-	for(QStringList::Iterator it=shownProps.begin(); it!=shownProps.end(); ++it)
+	for(QStringList::ConstIterator it=shownProps.constBegin(); it!=shownProps.constEnd(); ++it)
 	{
-		if((*it) == Kopete::Global::Properties::self()->fullName().key() )
+		if((*it) == Kopete::Global::Properties::self()->fullName().key())
 		{
-			QString name = formattedName();
+			const QString name = formattedName();
 			if(!name.isEmpty())
 			{
 				tip += i18nc("@label:textbox formatted name",
 							"<br /><b>Full Name:</b>&nbsp;<nobr>%1</nobr>", Qt::escape(name));
 			}
 		}
-		else if ((*it) == QString::fromLatin1("FormattedIdleTime"))
+		else if ((*it) == Kopete::Global::Properties::self()->idleTime().key())
 		{
-			QString time = formattedIdleTime();
+			const QString time = formattedIdleTime();
 			if(!time.isEmpty())
 			{
 				tip += i18nc("@label:textbox formatted idle time",
@@ -596,7 +606,7 @@ QString Contact::toolTip() const
 		}
 		else if ((*it) == QString::fromLatin1("homePage"))
 		{
-			QString url = property(*it).value().toString();
+			const QString url = property(*it).value().toString();
 			if(!url.isEmpty())
 			{
 				tip += i18nc("@label:textbox formatted url",
@@ -606,7 +616,7 @@ QString Contact::toolTip() const
 		}
 		else if ((*it) == Kopete::Global::Properties::self()->statusTitle().key() )
 		{
-			QString statusTitle = property(*it).value().toString();
+			const QString statusTitle = property(*it).value().toString();
 			if(!statusTitle.isEmpty())
 			{
 				tip += i18nc("@label:textbox formatted status title",
@@ -615,7 +625,7 @@ QString Contact::toolTip() const
 		}
 		else if ((*it) == Kopete::Global::Properties::self()->statusMessage().key() )
 		{
-			QString statusmsg = property(*it).value().toString();
+			const QString statusmsg = property(*it).value().toString();
 			if(!statusmsg.isEmpty())
 			{
 				tip += i18nc("@label:textbox formatted status message",
@@ -751,13 +761,13 @@ void Kopete::Contact::slotUnblock()
 
 void Kopete::Contact::setNickName( const QString &name )
 {
-	QString oldNickName = nickName();
+	const QString oldNickName = nickName();
 	setProperty( Kopete::Global::Properties::self()->nickName(), name );
 }
 
 QString Kopete::Contact::nickName() const
 {
-	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
+	const QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
 	if( !nick.isEmpty() )
 		return nick;
 
