@@ -21,6 +21,7 @@
 #include "kopetemetacontact.h"
 #include "kopetemetacontact_p.h"
 
+#include <QTextDocument>
 
 #include <kabc/addressbook.h>
 #include <kabc/addressee.h>
@@ -29,6 +30,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kdeversion.h>
+#include <knotification.h>
 
 #include "kabcpersistence.h"
 #include "kopetecontactlist.h"
@@ -40,13 +42,15 @@
 #include "kopetegroup.h"
 #include "kopeteglobal.h"
 #include "kopeteuiglobal.h"
+#include "kopetebehaviorsettings.h"
+#include "kopeteemoticons.h"
 
 namespace Kopete {
 
 MetaContact::MetaContact()
-	: ContactListElement( ContactList::self() )
+	: ContactListElement( ContactList::self() ), d(new Private())
 {
-	d = new Private;
+	d->metaContactId = QUuid::createUuid();
 
 	connect( this, SIGNAL( pluginDataChanged() ), SIGNAL( persistentDataChanged() ) );
 	connect( this, SIGNAL( iconChanged( Kopete::ContactListElement::IconState, const QString & ) ), SIGNAL( persistentDataChanged() ) );
@@ -65,6 +69,7 @@ MetaContact::MetaContact()
 	addToGroup( Group::topLevel() );
 			 // I'm not sure this is correct -Olivier
 			 // we probably should do the check in groups() instead
+
 }
 
 MetaContact::~MetaContact()
@@ -72,6 +77,16 @@ MetaContact::~MetaContact()
 	delete d;
 }
 
+QUuid MetaContact::metaContactId() const
+{
+	return d->metaContactId;
+}
+
+void MetaContact::setMetaContactId( const QUuid& newUuid)
+{
+	d->metaContactId = newUuid;
+}
+
 void MetaContact::addContact( Contact *c )
 {
 	if( d->contacts.contains( c ) )
@@ -83,7 +98,6 @@ void MetaContact::addContact( Contact *c )
 		const QString oldDisplayName = displayName();
 
 		d->contacts.append( c );
-
 		connect( c, SIGNAL( onlineStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ),
 			SLOT( slotContactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus &, const Kopete::OnlineStatus & ) ) );
 
@@ -141,7 +155,6 @@ void MetaContact::updateOnlineStatus()
 	}
 }
 
-
 void MetaContact::removeContact(Contact *c, bool deleted)
 {
 	if( !d->contacts.contains( c ) )
@@ -157,7 +170,7 @@ void MetaContact::removeContact(Contact *c, bool deleted)
 		QString currDisplayName = displayName();
 
 		d->contacts.removeAll( c );
-		
+
 		// if the contact was a source of property data, clean
 		if (displayNameSourceContact() == c)
 			setDisplayNameSourceContact(0L);
@@ -415,7 +428,7 @@ Contact *MetaContact::execute()
 	return 0L;
 }
 
-unsigned long int MetaContact::idleTime() const
+quint32 MetaContact::idleTime() const
 {
 	unsigned long int time = 0;
 	QListIterator<Contact *> it( d->contacts );
@@ -423,7 +436,7 @@ unsigned long int MetaContact::idleTime() const
 	{
 		Contact *c = it.next();
 		unsigned long int i = c->idleTime();
-		if( c->isOnline() && i < time || time == 0 )
+		if( (c->isOnline() && i < time) || time == 0 )
 		{
 			time = i;
 		}
@@ -489,7 +502,8 @@ bool MetaContact::isOnline() const
 	QListIterator<Contact *> it( d->contacts );
 	while ( it.hasNext() )
 	{
-		if( it.next()->isOnline() )
+		Contact* c = it.next();
+		if( c && c->isOnline() )
 			return true;
 	}
 	return false;
@@ -546,15 +560,29 @@ void MetaContact::sendFile( const KUrl &sourceURL, const QString &altFileName, u
 	contact->sendFile( sourceURL, altFileName, fileSize );
 }
 
-void MetaContact::emitAboutToSave()
+void MetaContact::serialize()
 {
-	emit aboutToSave( this );
+	clearPluginContactData();
+
+	QSet<Kopete::Protocol*> protocolSet;
+	foreach ( Kopete::Contact* c, contacts() )
+	{
+		Kopete::Protocol* protocol = c->protocol();
+		if ( !protocolSet.contains( protocol ) )
+		{
+			protocolSet.insert( protocol );
+			protocol->serialize( this );
+		}
+	}
 }
 
 void MetaContact::slotContactStatusChanged( Contact * c, const OnlineStatus &status, const OnlineStatus &/*oldstatus*/  )
 {
 	updateOnlineStatus();
 	emit contactStatusChanged( c, status );
+
+	if ( c != c->account()->myself() )
+		onlineStatusNotification( c );
 }
 
 void MetaContact::setDisplayName( const QString &name )
@@ -598,7 +626,6 @@ void MetaContact::setDisplayName( const QString &name )
 		while (  it.hasNext() )
 			( it.next() )->sync(Contact::DisplayNameChanged);
 	}
-
 }
 
 QString MetaContact::customDisplayName() const
@@ -613,8 +640,8 @@ QString MetaContact::displayName() const
 	{
 		// kabc source, try to get from addressbook
 		// if the metacontact has a kabc association
-		if ( !metaContactId().isEmpty() )
-			return nameFromKABC(metaContactId());
+		if ( !kabcId().isEmpty() )
+			return nameFromKABC(kabcId());
 	}
 	else if ( source == SourceContact || d->displayName.isEmpty())
 	{
@@ -666,8 +693,8 @@ QString nameFromContact( Kopete::Contact *c) /*const*/
 	if ( c->hasProperty( Kopete::Global::Properties::self()->nickName().key() ) )
 		contactName = c->property( Global::Properties::self()->nickName()).value().toString();
 
-				//the replace is there to workaround the Bug 95444
-	return contactName.isEmpty() ? c->contactId() : contactName.replace('\n',QString::fromUtf8(""));
+				//the remove is there to workaround the Bug 95444
+	return contactName.isEmpty() ? c->contactId() : contactName.remove('\n');
 }
 
 KUrl MetaContact::customPhoto() const
@@ -776,9 +803,7 @@ void MetaContact::setDisplayNameSourceContact( Contact *contact )
 	Contact *old = d->displayNameSourceContact;
 	d->displayNameSourceContact = contact;
 	if ( displayNameSource() == SourceContact )
-	{
 		emit displayNameChanged( nameFromContact(old), nameFromContact(contact));
-	}
 }
 
 void MetaContact::setPhotoSourceContact( Contact *contact )
@@ -792,7 +817,7 @@ void MetaContact::setPhotoSourceContact( Contact *contact )
 		if ( contact->hasProperty( Kopete::Global::Properties::self()->photo().key() ) )
 		{
 			photoProp = contact->property( Kopete::Global::Properties::self()->photo().key() ).value();
-		
+
 			if(photoProp.canConvert( QVariant::Image ))
 			{
 				d->contactPicture.setPicture( photoProp.value<QImage>() );
@@ -805,7 +830,19 @@ void MetaContact::setPhotoSourceContact( Contact *contact )
 			{
 				d->contactPicture.setPicture(photoProp.toString());
 			}
+			else
+			{
+				d->contactPicture.clear();
+			}
 		}
+		else
+		{
+			d->contactPicture.clear();
+		}
+	}
+	else
+	{
+		d->contactPicture.clear();
 	}
 
 	if ( photoSource() == SourceContact )
@@ -847,17 +884,57 @@ void MetaContact::slotPropertyChanged( PropertyContainer* _subcontact, const QSt
 				// as the current one is null, lets use this new one
 				if (picture().isNull())
 					setPhotoSourceContact(subcontact);
-					
+
 			}
 			else if(photoSourceContact() == subcontact)
 			{
 				if(d->photoSyncedWithKABC)
 					setPhotoSyncedWithKABC(true);
-					
+
 				setPhotoSourceContact(subcontact);
 			}
 		}
 	}
+
+	if ( (key == Kopete::Global::Properties::self()->statusMessage().key() ||
+	     key == Kopete::Global::Properties::self()->statusTitle().key()) && oldValue != newValue )
+	{
+		QString statusText;
+
+		bool allOffline = !this->isOnline();
+		if ( newValue.toString().isEmpty() || ( !subcontact->isOnline() && !allOffline ) )
+		{
+			// try to find a more suitable away message to be displayed when:
+			// -new away message is empty or
+			// -contact who set it is offline and there are contacts online in the metacontact
+			foreach ( Kopete::Contact *c, d->contacts )
+			{
+				QString curStatusText( c->property( key ).value().toString() );
+				if ( ( allOffline || c->isOnline() ) && !curStatusText.isEmpty() )
+				{
+					// display this contact's away message when:
+					// -this contact's away message is not empty and
+					// -this contact is online or there are no contacts online at all
+					statusText = curStatusText;
+					break;
+				}
+			}
+		}
+		else
+		{
+			// just use new away message when:
+			// -new away message is not empty and
+			// -contact who set it is online or there are no contacts online at all
+			statusText = newValue.toString();
+		}
+
+		if ( key == Kopete::Global::Properties::self()->statusMessage().key() )
+			d->statusMessage.setMessage( statusText );
+		else
+			d->statusMessage.setTitle( statusText );
+
+		emit statusMessageChanged( this );
+	}
 }
 
 void MetaContact::moveToGroup( Group *from, Group *to )
@@ -869,7 +946,11 @@ void MetaContact::moveToGroup( Group *from, Group *to )
 		return;
 	}
 
-	if ( !to || groups().contains( to )  )
+	// Do nothing (same group)
+	if ( from == to )
+		return;
+
+	if ( !to || groups().contains( to ) )
 	{
 		// We're removing, not moving, because 'to' is illegal
 		removeFromGroup( from );
@@ -923,6 +1004,7 @@ void MetaContact::addToGroup( Group *to )
 	if ( d->temporary && to->type() != Group::Temporary )
 		return;
 
+	// FIXME: This breaks copying MC with drag&drop from topLevel group
 	if ( d->groups.contains( Group::topLevel() ) )
 	{
 		d->groups.removeAll( Group::topLevel() );
@@ -958,6 +1040,11 @@ void Kopete::MetaContact::setAddressBookField( Kopete::Plugin * /* p */, const Q
 	d->addressBook[ app ][ key ] = value;
 }
 
+Kopete::StatusMessage MetaContact::statusMessage() const
+{
+	return d->statusMessage;
+}
+
 void MetaContact::slotPluginLoaded( Plugin *p )
 {
 	if( !p )
@@ -970,6 +1057,16 @@ void MetaContact::slotPluginLoaded( Plugin *p )
 	}
 }
 
+void MetaContact::slotProtocolLoaded( Protocol *p )
+{
+	if( !p )
+		return;
+
+	ContactDataList dataList = pluginContactData( p );
+	if ( !dataList.isEmpty() )
+		p->deserializeContactList( this, dataList );
+}
+
 void MetaContact::slotAllPluginsLoaded()
 {
 	// Now that the plugins and subcontacts are loaded, set the source contact.
@@ -980,7 +1077,7 @@ void MetaContact::slotAllPluginsLoaded()
 void MetaContact::slotUpdateAddressBookPicture()
 {
 	KABC::AddressBook* ab = KABCPersistence::self()->addressBook();
-	QString id = metaContactId();
+	QString id = kabcId();
 	if ( !id.isEmpty() && !id.contains(':') )
 	{
 		KABC::Addressee theAddressee = ab->findByUid(id);
@@ -1023,9 +1120,9 @@ void MetaContact::setTemporary( bool isTemporary, Group *group )
 		moveToGroup(temporaryGroup, group ? group : Group::topLevel());
 }
 
-QString MetaContact::metaContactId() const
+QString MetaContact::kabcId() const
 {
-	if(d->metaContactId.isEmpty())
+	if(d->kabcId.isEmpty())
 	{
 		if(d->contacts.isEmpty())
 			return QString();
@@ -1034,12 +1131,12 @@ QString MetaContact::metaContactId() const
 			return QString();
 		return c->protocol()->pluginId()+QString::fromUtf8(":")+c->account()->accountId()+QString::fromUtf8(":") + c->contactId() ;
 	}
-	return d->metaContactId;
+	return d->kabcId;
 }
 
-void MetaContact::setMetaContactId( const QString& newMetaContactId )
+void MetaContact::setKabcId( const QString& newKabcId )
 {
-	if(newMetaContactId == d->metaContactId)
+	if(newKabcId == d->kabcId)
 		return;
 
 	// 1) Check the Id is not already used by another contact
@@ -1051,7 +1148,7 @@ void MetaContact::setMetaContactId( const QString& newMetaContactId )
 
 	// Don't remove IM addresses from kabc if we are changing contacts;
 	// other programs may have written that data and depend on it
-	d->metaContactId = newMetaContactId;
+	d->kabcId = newKabcId;
 	if ( loading() )
 	{
 		slotUpdateAddressBookPicture();
@@ -1096,9 +1193,9 @@ void MetaContact::setPhotoSyncedWithKABC(bool b)
 				return;
 		}
 
-		if ( !d->metaContactId.isEmpty() && !newValue.isNull())
+		if ( !d->kabcId.isEmpty() && !newValue.isNull())
 		{
-			KABC::Addressee theAddressee = KABCPersistence::self()->addressBook()->findByUid( metaContactId() );
+			KABC::Addressee theAddressee = KABCPersistence::self()->addressBook()->findByUid( kabcId() );
 
 			if ( !theAddressee.isEmpty() )
 			{
@@ -1137,6 +1234,103 @@ QList<Contact *> MetaContact::contacts() const
 	return d->contacts;
 }
 
+void MetaContact::onlineStatusNotification( Kopete::Contact * c )
+{
+	// comparing the status of the previous and new preferred contact is the determining factor in deciding to notify
+	Kopete::OnlineStatus newNotifyOnlineStatus;
+
+	Kopete::Contact * pc = preferredContact();
+	if ( pc )
+		newNotifyOnlineStatus = pc->onlineStatus();
+	else // the last child contact has gone offline or otherwise unreachable, so take the changed contact's online status
+		newNotifyOnlineStatus = c->onlineStatus();
+
+	// ensure we are not suppressing notifications, because connecting or disconnected
+	if ( !c->account()->suppressStatusNotification() && c->account()->isConnected()
+	     && c->account()->myself()->onlineStatus().status() != OnlineStatus::Connecting
+	     && (Kopete::BehaviorSettings::self()->enableEventsWhileAway() || !c->account()->isAway()) )
+	{
+		// figure out what's happened
+		enum ChangeType { noChange, noEvent, signedIn, changedStatus, signedOut };
+		ChangeType t = noChange;
+
+		// first, exclude changes due to blocking or subscription changes at the protocol level
+		if ( d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Unknown || newNotifyOnlineStatus.status() == Kopete::OnlineStatus::Unknown )
+		{
+			t = noEvent; // This means the contact's changed from or to unknown - due to a protocol state change, not a contact state change
+		}
+		else
+		{ // we're dealing with a genuine contact state change
+			if ( d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Offline )
+			{
+				if ( newNotifyOnlineStatus.status() != Kopete::OnlineStatus::Offline )
+				{
+					t = signedIn;	// contact has gone from offline to something else, it's a sign-in
+				}
+			}
+			else if ( d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Online
+			          || d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Away
+			          || d->notifyOnlineStatus.status() == Kopete::OnlineStatus::Invisible)
+			{
+				if ( newNotifyOnlineStatus.status() == Kopete::OnlineStatus::Offline )
+				{
+					t = signedOut;	// contact has gone from an online state to an offline state, it's a sign out
+				}
+				else if ( d->notifyOnlineStatus > newNotifyOnlineStatus || d->notifyOnlineStatus < newNotifyOnlineStatus ) // operator!= is useless because it's an identity operator, not an equivalence operator
+				{
+					// contact has changed online states, it's a status change,
+					// and the preferredContact changed status, or there is a new preferredContacat
+					// so it's worth notifying
+					t = changedStatus;
+				}
+			}
+			else if ( d->notifyOnlineStatus != newNotifyOnlineStatus )
+			{
+				// catch-all for any other status change we don't know about
+				t = noEvent;
+			}
+		}
+
+		// now issue the appropriate notification
+		KNotification *notify = 0;
+		switch ( t )
+		{
+		case noEvent:
+		case noChange:
+			break;
+		case signedIn:
+			notify = new KNotification( QString("kopete_contact_online"), Kopete::UI::Global::mainWidget() );
+			notify->setActions( QStringList( i18nc("@action", "Chat") ) );
+			break;
+		case changedStatus:
+			notify = new KNotification( QString("kopete_contact_status_change"), Kopete::UI::Global::mainWidget() );
+			notify->setActions( QStringList( i18nc("@action", "Chat") ) );
+			break;
+		case signedOut:
+			notify = new KNotification( QString("kopete_contact_offline"), Kopete::UI::Global::mainWidget() );
+			break;
+		}
+
+		if( notify )
+		{
+			QString text = i18n( "<qt><i>%1</i> is now %2.</qt>",
+			                     Kopete::Emoticons::parseEmoticons( Qt::escape( displayName() ) ),
+			                     Qt::escape( c->onlineStatus().description() ) );
+
+			notify->setText( text );
+			notify->setPixmap( QPixmap::fromImage( picture().image() ) );
+			connect( notify, SIGNAL(activated(unsigned int)) , this, SLOT(execute()) );
+
+			notify->addContext( qMakePair( QString::fromLatin1("contact"), metaContactId().toString() ) );
+			foreach( Kopete::Group *g , groups() )
+			{
+				notify->addContext( qMakePair( QString::fromLatin1("group") , QString::number( g->groupId() ) ) );
+			}
+			notify->sendEvent();
+		}
+	}
+	d->notifyOnlineStatus = newNotifyOnlineStatus;
+}
 
 
 } //END namespace Kopete
