@@ -1,12 +1,12 @@
 /*
     kopeteonlinestatus.cpp - Kopete Online Status
 
-    Copyright (c) 2003 by Martijn Klingens <klingens@kde.org>
-    Copyright (c) 2003 by Duncan Mac-Vicar Prett <duncan@kde.org>
-    Copyright (c) 2003 by Will Stephenson <lists@stevello.free-online.co.uk>
-    Copyright (c) 2004 by Olivier Goffart <ogoffart @ tiscalinet.be>
+    Copyright (c) 2003      by Martijn Klingens <klingens@kde.org>
+    Copyright (c) 2003      by Duncan Mac-Vicar Prett <duncan@kde.org>
+    Copyright (c) 2003      by Will Stephenson <wstephenson@kde.org>
+    Copyright (c) 2004-2008 by Olivier Goffart <ogoffart@kde.org>
 
-    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2007 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -21,6 +21,7 @@
 #include "kopeteonlinestatus.h"
 #include "kopeteonlinestatusmanager.h"
 
+#include "kopeteidentity.h"
 #include "kopeteprotocol.h"
 #include "kopeteaccount.h"
 #include "kopetecontact.h"
@@ -28,10 +29,47 @@
 #include <kiconeffect.h>
 #include <kdebug.h>
 #include <klocale.h>
-#include <kstaticdeleter.h>
-#include <kapplication.h>
+#include <QPixmap>
+#include <QIconEngineV2>
+#include <QPainter>
 
+namespace Kopete
+{
 
+class OnlineStatusIconEngine : public QIconEngineV2
+{
+public:
+	OnlineStatusIconEngine( const OnlineStatus &s , const QString& i,
+	                        const QColor &c, bool _idle )
+		: status(s) , icon(i), color(c), idle(_idle) {}
+
+	virtual QIconEngineV2 *clone() const
+	{ return new OnlineStatusIconEngine(status,icon,color,idle); }
+
+	virtual QString key () const
+	{ return OnlineStatusManager::self()->fingerprint( status, icon, 0, color, idle ); }
+
+	QPixmap pixmap ( const QSize & size, QIcon::Mode mode, QIcon::State state )
+	{
+		const int iconSize = qMin(size.width(), size.height());
+		QIcon i(OnlineStatusManager::self()->cacheLookupByObject( status, icon, iconSize, color, idle ));
+		return i.pixmap(size, mode, state);
+	}
+
+	void paint( QPainter * painter, const QRect & rect, QIcon::Mode mode, QIcon::State state )
+	{
+		QPixmap pix = pixmap(rect.size() , mode, state);
+		painter->drawPixmap(rect, pix);
+	}
+
+private:
+	OnlineStatus status;
+	QString icon;
+	QColor color;
+	bool idle;
+};
+
+}
 
 using namespace Kopete;
 
@@ -45,13 +83,15 @@ public:
 	unsigned internalStatus;
 	QStringList overlayIcons;
 	QString description;
+	QString caption;
+	OnlineStatusManager::Categories categories;
+	OnlineStatusManager::Options options;
 	unsigned refCount;
 
 	QString protocolIcon() const
 	{
 		return protocol ?  protocol->pluginIcon() : QString::fromLatin1( "unknown" );
 	}
-
 };
 
 /**
@@ -80,10 +120,12 @@ OnlineStatus::OnlineStatus( StatusType status, unsigned weight, Protocol *protoc
 	d->overlayIcons = overlayIcons;
 	d->protocol = protocol;
 	d->description = description;
+	d->categories = 0x00;
+	d->options = 0x00;
 }
 
 OnlineStatus::OnlineStatus( StatusType status, unsigned weight, Protocol *protocol, unsigned internalStatus,
-   const QStringList &overlayIcons, const QString &description, const QString &caption, unsigned int categories , unsigned int options )
+   const QStringList &overlayIcons, const QString &description, const QString &caption, OnlineStatusManager::Categories categories , OnlineStatusManager::Options options )
 	 : d( new Private )
 {
 	d->status = status;
@@ -92,8 +134,11 @@ OnlineStatus::OnlineStatus( StatusType status, unsigned weight, Protocol *protoc
 	d->overlayIcons = overlayIcons;
 	d->protocol = protocol;
 	d->description = description;
+	d->caption = caption;
+	d->categories = categories;
+	d->options = options;
 
-	OnlineStatusManager::self()->registerOnlineStatus(*this, caption, categories, options );
+	OnlineStatusManager::self()->registerOnlineStatus( *this );
 }
 
 OnlineStatus::OnlineStatus( StatusType status )
@@ -103,6 +148,8 @@ OnlineStatus::OnlineStatus( StatusType status )
 	d->internalStatus = 0;
 	d->weight = 0;
 	d->protocol = 0L;
+	d->categories = 0x00;
+	d->options = 0x00;
 
 	switch( status )
 	{
@@ -124,7 +171,7 @@ OnlineStatus::OnlineStatus( StatusType status )
 	case Unknown:
 	default:
 		d->description = i18n( "Unknown" );
-		d->overlayIcons = QString::fromLatin1("status_unknown");
+		d->overlayIcons = QStringList( QString::fromLatin1("status_unknown") );
 		break;
 
 	}
@@ -137,7 +184,9 @@ OnlineStatus::OnlineStatus()
 	d->internalStatus = 0;
 	d->weight = 0;
 	d->protocol = 0L;
-	d->overlayIcons = QString::fromLatin1( "status_unknown" );
+	d->overlayIcons = QStringList( QString::fromLatin1( "status_unknown" ) );
+	d->categories = 0x00;
+	d->options = 0x00;
 }
 
 OnlineStatus::OnlineStatus( const OnlineStatus &other )
@@ -147,7 +196,14 @@ OnlineStatus::OnlineStatus( const OnlineStatus &other )
 
 bool OnlineStatus::operator==( const OnlineStatus &other ) const
 {
-	return d->internalStatus == other.d->internalStatus && d->protocol == other.d->protocol;
+	if ( d->internalStatus == other.d->internalStatus && d->protocol == other.d->protocol &&
+	     d->weight == other.d->weight && d->overlayIcons == other.d->overlayIcons &&
+	     d->description == other.d->description )
+	{
+		return true;
+	}
+
+	return false;
 }
 
 bool OnlineStatus::operator!=( const OnlineStatus &other ) const
@@ -212,6 +268,21 @@ Protocol* OnlineStatus::protocol() const
 	return d->protocol;
 }
 
+QString OnlineStatus::caption() const
+{
+	return d->caption;
+}
+
+OnlineStatusManager::Categories OnlineStatus::categories() const
+{
+	return d->categories;
+}
+
+OnlineStatusManager::Options OnlineStatus::options() const
+{
+	return d->options;
+}
+
 bool OnlineStatus::isDefinitelyOnline() const
 {
 	if ( status() == Offline || status() == Connecting || status() == Unknown )
@@ -219,9 +290,15 @@ bool OnlineStatus::isDefinitelyOnline() const
 	return true;
 }
 
-QPixmap OnlineStatus::iconFor( const Contact *contact, int size ) const
+QIcon OnlineStatus::iconFor( const Contact *contact ) const
 {
-	return OnlineStatusManager::self()->cacheLookupByMimeSource( mimeSourceFor( contact, size ) );
+	QString iconName = contact->icon();
+	if ( iconName.isNull() )
+		iconName = contact->account()->customIcon();
+	if ( iconName.isNull() )
+		iconName = d->protocolIcon();
+	return QIcon(new OnlineStatusIconEngine( *this, iconName,
+		     contact->account()->color(), contact->idleTime() >= 10*60));
 }
 
 
@@ -229,6 +306,8 @@ QString OnlineStatus::mimeSourceFor( const Contact *contact, int size ) const
 {
 	// figure out what icon we should use for this contact
  	QString iconName = contact->icon();
+	if ( iconName.isNull() )
+		iconName = contact->account()->customIcon();
 	if ( iconName.isNull() )
 		iconName = d->protocolIcon();
 
@@ -236,15 +315,22 @@ QString OnlineStatus::mimeSourceFor( const Contact *contact, int size ) const
 	return mimeSource( iconName, size, contact->account()->color(),contact->idleTime() >= 10*60 );
 }
 
-QPixmap OnlineStatus::iconFor( const Account *account, int size ) const
+QIcon OnlineStatus::iconFor( const Account *account ) const
 {
-	return OnlineStatusManager::self()->cacheLookupByMimeSource( mimeSourceFor( account, size ) );
+	QString iconName = account->customIcon();
+	if ( iconName.isNull() )
+		iconName = d->protocolIcon();
+	return QIcon(new OnlineStatusIconEngine(*this, iconName, account->color(),false));
+
 }
 
 QString OnlineStatus::mimeSourceFor( const Account *account, int size ) const
 {
-	//FIXME: support Kopete::Account having knowledge of a custom icon
-	return mimeSource( d->protocolIcon(), size, account->color(), false );
+	QString iconName = account->customIcon();
+	if ( iconName.isNull() )
+		iconName = d->protocolIcon();
+
+	return mimeSource( iconName, size, account->color(), false );
 }
 
 QPixmap OnlineStatus::iconFor( const QString &mimeSource ) const
@@ -276,7 +362,7 @@ QString OnlineStatus::statusTypeToString(OnlineStatus::StatusType statusType)
 	return QString::fromLatin1(statusNames[0].name); // Unknown
 }
 
-OnlineStatus::StatusType OnlineStatus::statusStringToType(QString& string)
+OnlineStatus::StatusType OnlineStatus::statusStringToType(const QString& string)
 {
 	int size = sizeof(statusNames) / sizeof(statusNames[0]);
 
