@@ -229,7 +229,7 @@ void MeanwhileAccount::setStatusMessage(const Kopete::StatusMessage &statusMessa
 }
 
 void MeanwhileAccount::setOnlineStatus(const Kopete::OnlineStatus &status,
-        const Kopete::StatusMessage &reason)
+                                       const Kopete::StatusMessage &reason, const OnlineStatusOptions& options)
 {
     HERE;
     Kopete::OnlineStatus oldstatus = myself()->onlineStatus();
@@ -274,7 +274,7 @@ void MeanwhileAccount::slotSessionStateChange(Kopete::OnlineStatus status)
 
     if (status.isDefinitelyOnline() != oldstatus.isDefinitelyOnline()) {
         if (status.isDefinitelyOnline())
-            m_session->addContacts(contacts());
+            m_session->addContacts(contacts()); // FIXME: what about myself??
         emit isConnectedChanged();
     }
 }
