@@ -47,6 +47,7 @@
 #include <klocale.h>
 #include <kcodecs.h>
 #include <kmessagebox.h>
+#include <kdialog.h>
 #include <kpassivepopup.h>
 #include <kstandarddirs.h>
 
@@ -62,10 +63,13 @@
 #include "kopeteversion.h"
 #include "oscarversionupdater.h"
 #include "filetransferhandler.h"
+#include "chatroomhandler.h"
 #include "nscainfoevent.h"
 #include "oscarpresence.h"
 #include "oscarprotocol.h"
 #include "oscarstatusmanager.h"
+#include <kopetesockettimeoutwatcher.h>
+
 
 class OscarAccountPrivate : public Client::CodecProvider
 {
@@ -113,6 +117,7 @@ OscarAccount::OscarAccount(Kopete::Protocol *parent, const QString &accountID, b
 
 	d = new OscarAccountPrivate( *this );
 	d->engine = new Client( this );
+	QObject::connect( d->engine, SIGNAL(createClientStream(ClientStream**)), this, SLOT(createClientStream(ClientStream**)) );
 	d->engine->setIsIcq( isICQ );
 	// Set version capability
 	// last 4 bytes determine version
@@ -152,6 +157,8 @@ OscarAccount::OscarAccount(Kopete::Protocol *parent, const QString &accountID, b
 	                  this, SLOT( slotSendBuddyIcon() ) );
 	QObject::connect( d->engine, SIGNAL(incomingFileTransfer(FileTransferHandler*)),
 	                  this, SLOT(incomingFileTransfer(FileTransferHandler*)) );
+	QObject::connect( d->engine, SIGNAL(chatroomRequest(ChatRoomHandler*)),
+	                  this, SLOT(chatroomRequest(ChatRoomHandler*)) );
 
 	Kopete::TransferManager *tm = Kopete::TransferManager::transferManager();
 	QObject::connect( tm, SIGNAL(refused(const Kopete::FileTransferInfo&)),
@@ -236,7 +243,7 @@ void OscarAccount::loginActions()
 	}
 
 	kDebug(OSCAR_RAW_DEBUG) << "sending request for icon service";
-	d->engine->requestServerRedirect( 0x0010 );
+	d->engine->connectToIconServer();
 
 	if ( d->buddyIconDirty )
 		updateBuddyIconInSSI();
@@ -444,6 +451,41 @@ void OscarAccount::nonServerAddContactDialogClosed()
     d->olnscDialog = 0L;
 }
 
+void OscarAccount::chatroomRequest( ChatRoomHandler* handler )
+{
+	KGuiItem buttonYes( KStandardGuiItem::yes() );
+	KGuiItem buttonNo( KStandardGuiItem::no() );
+	buttonYes.setText( i18nc( "@action:button filter-yes", "%1", KStandardGuiItem::yes().text() ) );
+	buttonNo.setText( i18nc( "@action:button filter-no", "%1", KStandardGuiItem::no().text() ) );
+	i18nc( "@action:button post-filter", "." );
+
+	KDialog *dialog = new KDialog( NULL, Qt::Dialog );
+	dialog->setCaption( i18n( "Chat Room Invitation" ) );
+	dialog->setButtons( KDialog::Yes | KDialog::No );
+	dialog->setObjectName( "questionYesNoCancel" );
+	dialog->setModal( false );
+	dialog->showButtonSeparator( true );
+	dialog->setButtonGuiItem( KDialog::Yes, buttonYes );
+	dialog->setButtonGuiItem( KDialog::No, buttonNo );
+	dialog->setDefaultButton( KDialog::Yes );
+	dialog->setEscapeButton( KDialog::No );
+
+	QObject::connect( dialog, SIGNAL( yesClicked() ),
+	                  handler, SLOT( accept() ) );
+	QObject::connect( dialog, SIGNAL( noClicked() ),
+	                  handler, SLOT( reject() ) );
+	QObject::connect( handler, SIGNAL( joinChatRoom( const QString&, int ) ),
+	                  engine(), SLOT( joinChatRoom( const QString&, int ) ) );
+
+	KMessageBox::createKMessageBox( dialog, QMessageBox::Question,
+	                                ( handler->contact() + ": " + handler->invite() ), QStringList(),
+	                                QString(), NULL, KMessageBox::NoExec );
+
+	dialog->show();
+	dialog->raise();
+	dialog->activateWindow();
+}
+
 void OscarAccount::incomingFileTransfer( FileTransferHandler* ftHandler )
 {
 	QString sender = Oscar::normalize( ftHandler->contact() );
@@ -615,25 +657,32 @@ QString OscarAccount::sanitizedMessage( const QString& message ) const
 	int errLine = 0, errCol = 0;
 
 	QString msg = addQuotesAroundAttributes(message);
-	msg = makeWellFormedXML( msg ); // Official clients send crap so we have to sort it out.
+	msg = makeWellFormedXML( msg ); // Official AIM client send crap so we have to sort it out.
 	msg.replace( "<BR>", "<BR/>", Qt::CaseInsensitive );
 
 	doc.setContent( msg, false, &domError, &errLine, &errCol );
 	if ( !domError.isEmpty() ) //error parsing, do nothing
 	{
-		kDebug(OSCAR_AIM_DEBUG) << "error from dom document conversion: "
-			<< domError << "line:" << errLine << "col:" << errCol;
-		return sanitizedPlainMessage( message );
+		kDebug(OSCAR_AIM_DEBUG) << "error from dom document conversion: " << domError << "line:" << errLine << "col:" << errCol;
+
+		// HACK: for trillian which sends totaly mangled html (there are not ended font tags)
+		if ( message.indexOf( QRegExp( "[\\s]*<[\\s]*HTML[\\s]*>[\\s]*<[\\s]*BODY", Qt::CaseInsensitive ) ) != 0 )
+			return sanitizedPlainMessage( message );
+		else
+			return message;
 	}
 	else
 	{
 		kDebug(OSCAR_AIM_DEBUG) << "conversion to dom document successful."
 			<< "looking for font tags" << endl;
-		QDomNodeList fontTagList = doc.elementsByTagName( "FONT" );
+		QList<QDomNode> fontTagList = getElementsByTagNameCI( doc, "FONT" );
 		if ( fontTagList.count() == 0 )
 		{
-			kDebug(OSCAR_AIM_DEBUG) << "No font tags found. Returning normal message";
-			return sanitizedPlainMessage( message );
+			if ( message.indexOf( QRegExp( "[\\s]*<[\\s]*HTML[\\s]*>[\\s]*<[\\s]*BODY", Qt::CaseInsensitive ) ) != 0 )
+			{
+				kDebug(OSCAR_AIM_DEBUG) << "No html tags found. Returning normal message";
+				return sanitizedPlainMessage( message );
+			}
 		}
 		else
 		{
@@ -641,10 +690,10 @@ QString OscarAccount::sanitizedMessage( const QString& message ) const
 			uint numFontTags = fontTagList.count();
 			for ( uint i = 0; i < numFontTags; i++ )
 			{
-				QDomNode fontNode = fontTagList.item(i);
+				QDomNode fontNode = fontTagList.at(i);
 				QDomElement fontEl;
 				if ( !fontNode.isNull() && fontNode.isElement() )
-					fontEl = fontTagList.item(i).toElement();
+					fontEl = fontNode.toElement();
 				else
 					continue;
 				if ( fontEl.hasAttribute( "BACK" ) )
@@ -777,18 +826,6 @@ bool OscarAccount::changeContactGroupInSSI( const QString& contact, const QStrin
 	return true;
 }
 
-Connection* OscarAccount::setupConnection()
-{
-	//set up the clientstream
-	ClientStream* cs = new ClientStream( new QTcpSocket(), 0 );
-
-	Connection* c = new Connection( cs, "AUTHORIZER" );
-	c->setClient( d->engine );
-
-	return c;
-}
-
-
 bool OscarAccount::createContact(const QString &contactId,
 	Kopete::MetaContact *parentContact)
 {
@@ -937,18 +974,16 @@ void OscarAccount::ssiContactUpdated( const OContact& item )
 	Kopete::Contact* contact = contacts().value( item.name() );
 	if ( !contact )
 		return;
-	else
-	{
-		kDebug(OSCAR_RAW_DEBUG) << "Updating SSI Item";
-		OscarContact* oc = static_cast<OscarContact*>( contact );
-		oc->setSSIItem( item );
-	}
+		
+	kDebug(OSCAR_RAW_DEBUG) << "Updating SSI Item";
+	OscarContact* oc = static_cast<OscarContact*>( contact );
+	oc->setSSIItem( item );
 }
 
 void OscarAccount::userStartedTyping( const QString & contact )
 {
 	Kopete::Contact * ct = contacts().value( Oscar::normalize( contact ) );
-	if ( ct && contact != accountId() )
+	if ( ct )
 	{
 		OscarContact * oc = static_cast<OscarContact *>( ct );
 		oc->startedTyping();
@@ -958,7 +993,7 @@ void OscarAccount::userStartedTyping( const QString & contact )
 void OscarAccount::userStoppedTyping( const QString & contact )
 {
 	Kopete::Contact * ct = contacts().value( Oscar::normalize( contact ) );
-	if ( ct && contact != accountId() )
+	if ( ct )
 	{
 		OscarContact * oc = static_cast<OscarContact *>( ct );
 		oc->stoppedTyping();
@@ -1393,5 +1428,36 @@ QString OscarAccount::sanitizedPlainMessage( const QString& message ) const
 	return sanitizedMsg;
 }
 
+QList<QDomNode> OscarAccount::getElementsByTagNameCI( const QDomNode& node, const QString& tagName ) const
+{
+	QList<QDomNode> nodeList;
+
+	QDomNode childNode = node.firstChild();
+	while ( !childNode.isNull() )
+	{
+		nodeList.append( getElementsByTagNameCI( childNode, tagName ) );
+		if ( childNode.isElement() && childNode.nodeName().compare( tagName, Qt::CaseInsensitive ) == 0 )
+			nodeList.append( childNode );
+
+		childNode = childNode.nextSibling();
+	}
+	return nodeList;
+}
+
+void OscarAccount::createClientStream( ClientStream **clientStream )
+{
+	QTcpSocket* tcpSocket = new QTcpSocket();
+	ClientStream *cs = new ClientStream( tcpSocket, 0 );
+	
+	Kopete::SocketTimeoutWatcher* timeoutWatcher = Kopete::SocketTimeoutWatcher::watch(tcpSocket);
+	if ( timeoutWatcher )
+	{
+		QObject::connect( timeoutWatcher, SIGNAL(error(QAbstractSocket::SocketError)),
+		                  cs, SLOT(socketError(QAbstractSocket::SocketError)) );
+	}
+
+	*clientStream = cs;
+}
+
 #include "oscaraccount.moc"
 //kate: tab-width 4; indent-mode csands;
