@@ -1,3 +1,4 @@
+
 /*
     yahoocontact.cpp - Yahoo Contact
 
@@ -271,6 +272,17 @@ QString YahooContact::prepareMessage( const QString &messageText )
 		}
 	}
 
+	// find and remove background color formattings (not supported)
+	regExp.setPattern( "<span([^>]*)background-color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
+	pos = 0;
+	while ( pos >= 0 ) {
+		pos = regExp.indexIn( messageText, pos );
+		if ( pos >= 0 ) {
+			pos += regExp.matchedLength();
+			newMsg.replace( regExp, QLatin1String("<span\\1\\3>\\4</span>" ) );
+		}
+	}
+
 	// find and replace Color-formattings
 	regExp.setPattern( "<span([^>]*)color:#([0-9a-zA-Z]*)([^>]*)>(.*)</span>" );
 	pos = 0;
@@ -570,30 +582,25 @@ void YahooContact::buzzContact()
 	}
 }
 
-void YahooContact::setDisplayPicture(KTemporaryFile *f, int checksum)
+void YahooContact::setDisplayPicture(const QByteArray &data, int checksum)
 {
-	kDebug(YAHOO_GEN_DEBUG) ;
-	if( !f )
-		return;
-	// stolen from msncontact.cpp ;)
+	kDebug(YAHOO_GEN_DEBUG) << data.size();
+
 	setProperty( YahooProtocol::protocol()->iconCheckSum, checksum );
 
 	Kopete::AvatarManager::AvatarEntry entry;
 	entry.name = contactId();
 	entry.category = Kopete::AvatarManager::Contact;
 	entry.contact = this;
-	entry.image = QImage(f->fileName());
+	entry.image = QImage::fromData(data);
 	entry = Kopete::AvatarManager::self()->add(entry);
 
-	if (!entry.path.isNull())
+	if (!entry.dataPath.isNull())
 	{
 		setProperty( Kopete::Global::Properties::self()->photo(), QString() );
-		setProperty( Kopete::Global::Properties::self()->photo() , entry.path );
+		setProperty( Kopete::Global::Properties::self()->photo() , entry.dataPath );
 		emit displayPictureChanged();
 	}
-
-	f->setAutoRemove(true);
-	delete f;
 }
 
 
@@ -626,7 +633,7 @@ void YahooContact::inviteWebcam()
 	if ( KStandardDirs::findExe("jasper").isEmpty() )
 	{
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
-			i18n("I cannot find the Jasper image conversion program.\nJasper is required to render the Yahoo webcam images."
+			i18n("Unable to find the Jasper image conversion program.\nJasper is required to render Yahoo webcam images."
 			"\nPlease see %1 for further information.", QString("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") ) );
 		return;
 	}
@@ -681,7 +688,7 @@ void YahooContact::requestWebcam()
 	if ( KStandardDirs::findExe("jasper").isEmpty() )
 	{
 		KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error,
-			i18n("I cannot find the jasper image convert program.\njasper is required to render the yahoo webcam images."
+			i18n("Unable to find the Jasper image conversion program.\nJasper is required to render Yahoo webcam images."
 			"\nPlease see %1 for further information.", QString("http://wiki.kde.org/tiki-index.php?page=Kopete%20Webcam%20Support") ) );
 		return;
 	}
