@@ -2,7 +2,7 @@
  *
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: conwindow.h 212185 2003-03-07 22:11:39Z waba $
+ * $Id: conwindow.h 725496 2007-10-15 15:07:57Z mlaurent $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef _CONWINDOW_H_
@@ -30,9 +30,12 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qdialog.h>
-#include <qframe.h>
+#include <q3frame.h>
 #include <qevent.h>
 #include <qlayout.h>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QCloseEvent>
 
 class PPPStats;
 
@@ -58,7 +61,7 @@ public:
   void accounting(bool); // show/ hide accounting info
 
 public slots:
-  void slotAccounting(QString, QString);
+  void slotAccounting(const QString &, const QString &);
 
 private:
   QLabel *info1;
