@@ -19,11 +19,10 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "kpppwidget.h"
-
 #include <qapplication.h>
 #include <qcombobox.h>
 #include <qdir.h>
@@ -32,12 +31,15 @@
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qregexp.h>
-#include <kdialogbase.h>
-#include <qwhatsthis.h>
+//Added by qt3to4:
+#include <QGridLayout>
+#include <QKeyEvent>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
+#include <kpagedialog.h>
 
+#include <QMenu>
 #include <kaboutdata.h>
-#include <kapplication.h>
-#include <kbuttonbox.h>
 #include <kglobalsettings.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
@@ -47,14 +49,16 @@
 #include <kmessagebox.h>
 #include <kseparator.h>
 #include <kstandarddirs.h>
-#include <kwin.h>
+#include <kapplication.h>
+#include <kwindowsystem.h>
 #include <khelpmenu.h>
 #include <kpushbutton.h>
 #include <kguiitem.h>
-#include <kstdguiitem.h>
+#include <KStandardGuiItem>
 
 #include <stdlib.h>
 #include <errno.h>
+#include <ktoolinvocation.h>
 
 #include "runtests.h"
 
@@ -69,17 +73,30 @@
 #include "general.h"
 #include "modems.h"
 
+#include "kpppadaptor.h"
+
 // delay disconnection for a second
 #define DISCONNECT_DELAY 1000
 
 extern KPPPWidget *p_kppp;
 
 KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
-  : DCOPObject( "KpppIface" ), QWidget(parent, name)
+  : QWidget(parent)
   , acct(0)
   , m_bCmdlAccount (false)
   , m_bCmdlModem (false)
 {
+    KpppAdaptor *kpppAdaptor = new KpppAdaptor(this);
+    QDBusConnection::sessionBus().registerObject("/Kppp", this);
+
+    setObjectName( name );
+
+    connect( this, SIGNAL(sig_aboutToConnect()), kpppAdaptor, SIGNAL(aboutToConnect()) );
+    connect( this, SIGNAL(sig_aboutToDisconnect()), kpppAdaptor, SIGNAL(aboutToDisconnect()) );
+    connect( this, SIGNAL(sig_connected()), kpppAdaptor, SIGNAL(connected()) );
+    connect( this, SIGNAL(sig_disconnected()), kpppAdaptor, SIGNAL(disconnected()) );
+
+
   tabWindow = 0;
 
   // before doing anything else, run a few tests
@@ -90,19 +107,22 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   installEventFilter(this);
 
-  QVBoxLayout *tl = new QVBoxLayout(this, 10, 10);
+  QVBoxLayout *tl = new QVBoxLayout(this);
+  tl->setSpacing(10);
+  tl->setMargin(10);
 
-  l1 = new QGridLayout(4, 4);
+  l1 = new QGridLayout();
   tl->addLayout(l1);
-  l1->addColSpacing(0, 10);
-  l1->addColSpacing(3, 10);
-  l1->setColStretch(1, 3);
-  l1->setColStretch(2, 4);
+  l1->addItem(new QSpacerItem(10, 0), 0, 0);
+  l1->addItem(new QSpacerItem(10, 0), 0, 3);
+  l1->setColumnStretch(1, 3);
+  l1->setColumnStretch(2, 4);
 
   label1 = new QLabel(i18n("C&onnect to: "), this);
   l1->addWidget(label1, 0, 1);
 
-  connectto_c = new QComboBox(false, this);
+  connectto_c = new QComboBox(this);
+  connectto_c->setEditable( false );
   label1->setBuddy(connectto_c);
 
   connect(connectto_c, SIGNAL(activated(int)),
@@ -111,7 +131,8 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   label7 = new QLabel(i18n("Use &modem: "), this);
   // l1->addWidget(label7, 1, 1); (done in resetmodems())
-  modem_c = new QComboBox(false, this);
+  modem_c = new QComboBox(this);
+  modem_c->setEditable( false );
   label7->setBuddy(connectto_c);
   m_bModemCShown = false;
 
@@ -136,8 +157,8 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 		     "<b>Important</b>: case is important here:\n"
 		     "<i>myusername</i> is not the same as <i>MyUserName</i>.");
 
-  QWhatsThis::add(ID_Label,tmp);
-  QWhatsThis::add(ID_Edit,tmp);
+  ID_Label->setWhatsThis(tmp);
+  ID_Edit->setWhatsThis(tmp);
 
   PW_Label = new QLabel(i18n("&Password:"), this);
   l1->addWidget(PW_Label, 3, 1);
@@ -157,8 +178,8 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 	     "<b>Important</b>: case is important here:\n"
 	     "<i>mypassword</i> is not the same as <i>MyPassword</i>.");
 
-  QWhatsThis::add(PW_Label,tmp);
-  QWhatsThis::add(PW_Edit,tmp);
+  PW_Label->setWhatsThis(tmp);
+  PW_Edit->setWhatsThis(tmp);
 
    QHBoxLayout *l3 = new QHBoxLayout;
    tl->addSpacing(5);
@@ -171,7 +192,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
    log->setChecked(gpppdata.get_show_log_window());
    l3->addWidget(log);
 
-   QWhatsThis::add(log,
+   log->setWhatsThis(
  		  i18n("<p>This controls whether a log window is shown.\n"
  		       "A log window shows the communication between\n"
  		       "<i>kppp</i> and your modem. This will help you\n"
@@ -180,14 +201,14 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
  		       "Turn it off if <i>kppp</i> routinely connects without\n"
  		       "problems"));
 
-  fline = new KSeparator( KSeparator::HLine, this);
+  fline = new KSeparator( Qt::Horizontal, this);
   tl->addWidget(fline);
 
   QHBoxLayout *l2 = new QHBoxLayout;
   tl->addLayout(l2);
 
   int minw = 0;
-  quit_b = new KPushButton(KStdGuiItem::quit(), this);
+  quit_b = new KPushButton(KStandardGuiItem::quit(), this);
   connect( quit_b, SIGNAL(clicked()), SLOT(quitbutton()));
   if(quit_b->sizeHint().width() > minw)
       minw = quit_b->sizeHint().width();
@@ -200,12 +221,11 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   if(gpppdata.access() != KConfig::ReadWrite)
     setup_b->setEnabled(false);
 
-  help_b = new KPushButton(KStdGuiItem::help(), this);
+  help_b = new KPushButton(KStandardGuiItem::help(), this);
   connect( help_b, SIGNAL(clicked()), SLOT(helpbutton()));
 
-  KHelpMenu *helpMenu = new KHelpMenu(this, KGlobal::instance()->aboutData(), true);
-  help_b->setPopup((QPopupMenu*)helpMenu->menu());
-
+  KHelpMenu *helpMenu = new KHelpMenu(this, KGlobal::mainComponent().aboutData(), true);
+  help_b->setMenu((QMenu*)helpMenu->menu());
   if(help_b->sizeHint().width() > minw)
       minw = help_b->sizeHint().width();
 
@@ -237,25 +257,25 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   stats = new PPPStats;
 
-  KWin::setIcons(winId(), kapp->icon(), kapp->miniIcon());
+  KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
 
   // constructor of con_win reads position from config file
   con_win = new ConWindow(0, "conw", this, stats);
-  KWin::setIcons(con_win->winId(), kapp->icon(), kapp->miniIcon());
+  KWindowSystem::setIcons(con_win->winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
 
   statdlg = new PPPStatsDlg(0, "stats", this, stats);
   statdlg->hide();
 
-  debugwindow = new DebugWidget(0,"debugwindow");
-  KWin::setIcons(debugwindow->winId(), kapp->icon(), kapp->miniIcon());
-  debugwindow->hide();
+  debugwindow = new DebugWidget(0);
+  debugwindow->setObjectName( "debugwindow" );
+  KWindowSystem::setIcons(debugwindow->winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
 
   // load up the accounts combo box
 
   resetaccounts();
   resetmodems();
   con = new ConnectWidget(0, "con", stats);
-  KWin::setIcons(con->winId(), kapp->icon(), kapp->miniIcon() );
+  KWindowSystem::setIcons(con->winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)) );
   connect(this, SIGNAL(begin_connect()),con, SLOT(preinit()));
 
   QRect desk = KGlobalSettings::desktopGeometry(topLevelWidget());
@@ -276,8 +296,10 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 	  this, SLOT(stopAccounting()));
   connect(KApplication::kApplication(), SIGNAL(saveYourself()),
 	  this, SLOT(saveMyself()));
-  connect(KApplication::kApplication(), SIGNAL(shutDown()),
+  connect(KApplication::kApplication(), SIGNAL(aboutToQuit()),
 	  this, SLOT(shutDown()));
+  connect(con, SIGNAL(aboutToConnect()), this, SIGNAL(sig_aboutToConnect()));
+  connect(con, SIGNAL(connected()),      this, SIGNAL(sig_connected()));
 
   debugwindow->setGeometry(desk.center().x()+190, desk.center().y()-55,
 			   debugwindow->width(),debugwindow->height());
@@ -293,19 +315,19 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
 
   if(!m_strCmdlAccount.isEmpty()) {
     m_bCmdlAccount = true;
-    kdDebug(5002) << "cmdl_account: " << m_bCmdlAccount << endl;
+    kDebug(5002) << "cmdl_account: " << m_bCmdlAccount;
   }
 
   if(!m_strCmdlModem.isEmpty()) {
     m_bCmdlModem = true;
-    kdDebug(5002) << "cmdl_modem: " << m_bCmdlModem << endl;
+    kDebug(5002) << "cmdl_modem: " << m_bCmdlModem;
   }
 
   if(m_bCmdlModem){
     bool result = gpppdata.setModem(m_strCmdlModem);
     if (!result){
       QString string;
-      string = i18n("No such Modem:\n%1\nFalling back to default").arg(m_strCmdlModem);
+      string = i18n("No such Modem:\n%1\nFalling back to default", m_strCmdlModem);
       KMessageBox::error(this, string);
       m_bCmdlModem = false;
     }
@@ -315,7 +337,7 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
     bool result = gpppdata.setAccount(m_strCmdlAccount);
     if (!result){
       QString string;
-      string = i18n("No such Account:\n%1").arg(m_strCmdlAccount);
+      string = i18n("No such Account:\n%1", m_strCmdlAccount);
       KMessageBox::error(this, string);
       m_bCmdlAccount = false;
       show();
@@ -332,13 +354,6 @@ KPPPWidget::KPPPWidget( QWidget *parent, const char *name )
   if(!m_bCmdlAccount)
     showNews();
 #endif
-
-  // attach to the DCOP server, if possible
-  if (!kapp->dcopClient()->attach())
-    kdDebug(5002) << "Error: Could not connect to the DCOP server" << endl;
-  else
-    kapp->dcopClient()->registerAs(kapp->name(), true);
-
   // this timer will delay the actual disconnection DISCONNECTION_DELAY ms
   // to give applications time to shutdown, logout, whatever..
   disconnectTimer = new QTimer(this);
@@ -354,7 +369,7 @@ bool KPPPWidget::eventFilter(QObject *o, QEvent *e) {
   if(e->type() == QEvent::User) {
     switch(((SignalEvent*)e)->sigType()) {
     case SIGINT:
-      kdDebug(5002) << "Received a SIGINT" << endl;
+      kDebug(5002) << "Received a SIGINT";
       interruptConnection();
       break;
     case SIGCHLD:
@@ -381,16 +396,21 @@ bool KPPPWidget::eventFilter(QObject *o, QEvent *e) {
 
 void KPPPWidget::prepareSetupDialog() {
   if(tabWindow == 0) {
-    tabWindow = new KDialogBase( KDialogBase::Tabbed, i18n("KPPP Configuration"),
-                                 KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok,
-                                 kapp->mainWidget(), 0, true);
+    tabWindow = new KPageDialog( this );
+    tabWindow->setCaption( i18n("KPPP Configuration") );
+    tabWindow->setButtons( KDialog::Ok|KDialog::Cancel );
+    tabWindow->setDefaultButton(  KDialog::Ok );
+    tabWindow->setFaceType( KPageDialog::Tabbed );
+    tabWindow->setModal( true );
 
-
-    KWin::setIcons(tabWindow->winId(), kapp->icon(), kapp->miniIcon());
+    KWindowSystem::setIcons(tabWindow->winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop),IconSize(KIconLoader::Desktop)), qApp->windowIcon().pixmap(IconSize(KIconLoader::Small),IconSize(KIconLoader::Small)));
 
     //    tabWindow->setFixedSize( 365, 375 );
-
-    accounts = new AccountWidget(tabWindow->addPage( i18n("&Accounts"), i18n("Account Setup") ) );
+    QFrame *frame = new QFrame();
+    KPageWidgetItem *pageItem = new KPageWidgetItem( frame, i18n("&Accounts") );
+    pageItem->setHeader( i18n("Account Setup") );
+    tabWindow->addPage( pageItem );
+    accounts = new AccountWidget(frame);
     connect(accounts, SIGNAL(resetaccounts()),
 	    this, SLOT(resetaccounts()));
     connect(accounts, SIGNAL(resetCosts(const QString &)),
@@ -398,12 +418,27 @@ void KPPPWidget::prepareSetupDialog() {
     connect(accounts, SIGNAL(resetVolume(const QString &)),
 	    this, SLOT(resetVolume(const QString &)));
 
-    modems = new ModemsWidget(tabWindow->addPage( i18n("&Modems"), i18n("Modems Setup") ) );
+
+    frame = new QFrame();
+    pageItem = new KPageWidgetItem( frame, i18n("&Modems") );
+    pageItem->setHeader( i18n("Modems Setup") );
+    tabWindow->addPage( pageItem );
+    modems = new ModemsWidget(frame);
     connect(modems, SIGNAL(resetmodems()),
 	    this, SLOT(resetmodems()));
 
-    graph = new GraphSetup( tabWindow->addPage( i18n("&Graph"), i18n("Throughput Graph" ) ) );
-    general = new GeneralWidget( tabWindow->addPage( i18n("M&isc"), i18n("Miscellaneous Settings") ) );
+    frame = new QFrame();
+    pageItem = new KPageWidgetItem( frame, i18n("&Graph") );
+    pageItem->setHeader( i18n("Throughput Graph") );
+    tabWindow->addPage( pageItem );
+
+    graph = new GraphSetup( frame );
+
+    frame = new QFrame();
+    pageItem = new KPageWidgetItem( frame, i18n("M&isc") );
+    pageItem->setHeader( i18n("Miscellaneous Settings") );
+    tabWindow->addPage( pageItem );
+    general = new GeneralWidget( frame );
   }
 }
 
@@ -454,14 +489,14 @@ void KPPPWidget::resetaccounts() {
   //load the accounts
   for(int i=0; i < count; i++) {
     gpppdata.setAccountByIndex(i);
-     connectto_c->insertItem(gpppdata.accname());
+     connectto_c->addItem(gpppdata.accname());
   }
 
   //set the default account
   if(!gpppdata.defaultAccount().isEmpty()) {
     for(int i=0; i < count; i++)
-       if(gpppdata.defaultAccount() == connectto_c->text(i)) {
- 	connectto_c->setCurrentItem(i);
+       if(gpppdata.defaultAccount() == connectto_c->itemText(i)) {
+ 	connectto_c->setCurrentIndex(i);
 	gpppdata.setAccountByIndex(i);
 
 	ID_Edit->setText(gpppdata.storedUsername());
@@ -470,7 +505,7 @@ void KPPPWidget::resetaccounts() {
   }
   else
     if(count > 0) {
-       gpppdata.setDefaultAccount(connectto_c->text(0));
+       gpppdata.setDefaultAccount(connectto_c->itemText(0));
         gpppdata.save();
 	ID_Edit->setText(gpppdata.storedUsername());
 	PW_Edit->setText(gpppdata.storedPassword());
@@ -501,7 +536,7 @@ void KPPPWidget::resetmodems() {
   //load the modems
   for(int i=0; i < count; i++) {
     gpppdata.setModemByIndex(i);
-    modem_c->insertItem(gpppdata.modname());
+    modem_c->addItem(gpppdata.modname());
   }
 
   if (count > 1 && !m_bModemCShown) {
@@ -509,27 +544,27 @@ void KPPPWidget::resetmodems() {
       l1->addWidget(modem_c, 1, 2);
       m_bModemCShown = true;
   } else if (count <= 1 && m_bModemCShown){
-      l1->remove(label7);
-      l1->remove(modem_c);
+      l1->removeWidget(label7);
+      l1->removeWidget(modem_c);
       m_bModemCShown = false;
   }
-  label7->setShown(m_bModemCShown);
-  modem_c->setShown(m_bModemCShown);     
+  label7->setVisible(m_bModemCShown);
+  modem_c->setVisible(m_bModemCShown);
   layout()->invalidate();
   setFixedSize(sizeHint());
 
   //set the default modem
   if(!gpppdata.defaultModem().isEmpty()) {
     for(int i=0; i < count; i++)
-       if(gpppdata.defaultModem() == modem_c->text(i)) {
- 	modem_c->setCurrentItem(i);
+       if(gpppdata.defaultModem() == modem_c->itemText(i)) {
+ 	modem_c->setCurrentIndex(i);
 	gpppdata.setModemByIndex(i);
 
     }
   }
   else
     if(count > 0) {
-       gpppdata.setDefaultModem(modem_c->text(0));
+       gpppdata.setDefaultModem(modem_c->itemText(0));
         gpppdata.save();
     }
 }
@@ -559,13 +594,13 @@ void KPPPWidget::interruptConnection() {
 }
 
 void KPPPWidget::sigPPPDDied() {
-  kdDebug(5002) << "Received a SIGUSR1" << endl;
+  kDebug(5002) << "Received a SIGUSR1";
 
     // if we are not connected pppdpid is -1 so have have to check for that
     // in the followin line to make sure that we don't raise a false alarm
     // such as would be the case when the log file viewer exits.
     if(gpppdata.pppdRunning() || gpppdata.pppdError()) {
-      kdDebug(5002) << "It was pppd that died" << endl;
+      kDebug(5002) << "It was pppd that died";
 
       // when we killpppd() on Cancel in ConnectWidget
       // we set pppid to -1 so we won't
@@ -580,10 +615,9 @@ void KPPPWidget::sigPPPDDied() {
       // stop the disconnect timer (just in case)
       disconnectTimer->stop();
       // signal other applications that we are disconnected now
-      kapp->dcopClient()->emitDCOPSignal("KpppIface", "disconnected()", QByteArray());
-
-      kdDebug(5002) << "Executing command on disconnect since pppd has died." << endl;
-      QApplication::flushX();
+      emit  sig_disconnected();
+      kDebug(5002) << "Executing command on disconnect since pppd has died.";
+      QApplication::flush();
       execute_command(gpppdata.command_on_disconnect());
 
       stopAccounting();
@@ -619,22 +653,21 @@ void KPPPWidget::sigPPPDDied() {
 	    msg = i18n("<p>The pppd daemon died unexpectedly!</p>");
 	    Requester::rq->pppdExitStatus();
 	    if (Requester::rq->lastStatus != 99) {	// more recent pppds only
-		msg += i18n("<p>Exit status: %1").arg(Requester::rq->lastStatus);
+		msg += i18n("<p>Exit status: %1", Requester::rq->lastStatus);
 		msg += i18n("</p><p>See 'man pppd' for an explanation of the error "
 			    "codes or take a look at the kppp FAQ on "
-			    "  <a href=\"%1\">%2</a></p>")
-                       .arg("http://developer.kde.org/~kppp/index.html")
-                       .arg("http://developer.kde.org/~kppp/index.html");
+			    "  <a href=\"%1\">%1</a></p>",
+                        QString("http://developer.kde.org/~kppp/index.html"));
 	    }
 	}
 
-	if(KMessageBox::warningYesNo(0, msg, i18n("Error"), KStdGuiItem::ok(), i18n("&Details")) == KMessageBox::No)
+	if(KMessageBox::warningYesNo(0, msg, i18n("Error"), KStandardGuiItem::ok(), KGuiItem(i18n("&Details"))) == KMessageBox::No)
 	  PPPL_ShowLog();
       } else { /* reconnect on disconnect */
         if(gpppdata.waitCallback())
-          kdDebug(5002) << "Waiting for callback... " << endl;
+          kDebug(5002) << "Waiting for callback... ";
         else
-          kdDebug(5002) << "Trying to reconnect... " << endl;
+          kDebug(5002) << "Trying to reconnect... ";
 
         if(gpppdata.authMethod() == AUTH_PAP ||
 	   gpppdata.authMethod() == AUTH_CHAP ||
@@ -656,10 +689,10 @@ void KPPPWidget::sigPPPDDied() {
 
 
 void KPPPWidget::sigChld() {
-  kdDebug(5002) << "sigchld()" << endl;
+  kDebug(5002) << "sigchld()";
   //  pid_t id = wait(0L);
   //  if(id == helperPid && helperPid != -1) {
-  //    kdDebug(5002) << "It was the setuid child that died" << endl;
+  //    kDebug(5002) << "It was the setuid child that died";
  // helperPid = -1;
     QString msg = i18n("kppp's helper process just died.\n"
                        "Since further execution would be pointless, "
@@ -672,14 +705,14 @@ void KPPPWidget::sigChld() {
 
 
 void KPPPWidget::newdefaultaccount(int i) {
-  gpppdata.setDefaultAccount(connectto_c->text(i));
+  gpppdata.setDefaultAccount(connectto_c->itemText(i));
   gpppdata.save();
   ID_Edit->setText(gpppdata.storedUsername());
   PW_Edit->setText(gpppdata.storedPassword());
 }
 
 void KPPPWidget::newdefaultmodem(int i) {
-  gpppdata.setDefaultModem(modem_c->text(i));
+  gpppdata.setDefaultModem(modem_c->itemText(i));
   gpppdata.save();
 }
 
@@ -715,7 +748,7 @@ void KPPPWidget::beginConnect() {
     string = i18n("kppp cannot execute:\n %1\n"
     		   "Please make sure that you have given kppp "
 		   "setuid permission and that "
-		   "pppd is executable.").arg(gpppdata.pppdPath());
+		   "pppd is executable.", gpppdata.pppdPath());
     KMessageBox::error(this, string);
     return;
 
@@ -737,7 +770,7 @@ void KPPPWidget::beginConnect() {
 		   "your modem device properly "
 		   "and/or adjust the location of the modem device on "
 		   "the modem tab of "
-		   "the setup dialog.").arg(device);
+		   "the setup dialog.", device);
     KMessageBox::error(this, string);
     return;
   }
@@ -760,7 +793,7 @@ void KPPPWidget::beginConnect() {
 				   encodeWord(gpppdata.password()))) {
 	QString s;
 	s = i18n("Cannot create PAP/CHAP authentication\n"
-				     "file \"%1\"").arg(PAP_AUTH_FILE);
+				     "file \"%1\"", QString(PAP_AUTH_FILE));
 	KMessageBox::error(this, s);
 	return;
       }
@@ -775,13 +808,13 @@ void KPPPWidget::beginConnect() {
 
   hide();
 
-  QString tit = i18n("Connecting to: %1").arg(gpppdata.accname());
-  con->setCaption(tit);
+  QString tit = i18n("Connecting to: %1", gpppdata.accname());
+  con->setWindowTitle(tit);
   con->enableButtons();
   con->show();
 
   bool show_debug = gpppdata.get_show_log_window();
-  con->debug->setOn(show_debug);	// toggle button
+  con->debug->setChecked(show_debug);	// toggle button
   debugwindow->clear();
   if (!show_debug)
     debugwindow->hide();
@@ -797,22 +830,23 @@ void KPPPWidget::disconnect() {
   if (disconnectTimer->isActive()) return; // you had already pressed disconnect before
 
   // signal other applications that we are about to go offline now
-  kapp->dcopClient()->emitDCOPSignal("KpppIface", "aboutToDisconnect()", QByteArray());
+  emit sig_aboutToDisconnect();
+
   con_win->hide();
   con->show();
   con->disableButtons(); // will reenable them later in delayedDisconnect()
-  con->setCaption(i18n("Disconnecting..."));
+  con->setWindowTitle(i18n("Disconnecting..."));
 
   if (!gpppdata.command_before_disconnect().isEmpty()) {
     con->setMsg(i18n("Executing command before disconnection."));
 
-    kapp->processEvents();
-    QApplication::flushX();
+    qApp->processEvents();
+    QApplication::flush();
     pid_t id = execute_command(gpppdata.command_before_disconnect());
     int i, status;
 
     do {
-      kapp->processEvents();
+      qApp->processEvents();
       i = waitpid(id, &status, WNOHANG);
       usleep(500000);
     } while (i == 0 && errno == 0);
@@ -821,10 +855,11 @@ void KPPPWidget::disconnect() {
   con->setMsg(i18n("Announcing disconnection."));
 
   // this is no longer necessary since I'm delaying disconnection usign a QTimer
-  //  kapp->processEvents();
+  //  qApp->processEvents();
 
   // set the timer to call delayedDisconnect() in DISCONNECT_DELAY ms
-  disconnectTimer->start(DISCONNECT_DELAY, true);
+  disconnectTimer->setSingleShot(true);
+  disconnectTimer->start(DISCONNECT_DELAY);
 }
 
 void KPPPWidget::delayedDisconnect() {
@@ -835,9 +870,8 @@ void KPPPWidget::delayedDisconnect() {
   Requester::rq->killPPPDaemon();
 
   // signal other applications that we are disconnected now
-  kapp->dcopClient()->emitDCOPSignal("KpppIface", "disconnected()", QByteArray());
-
-  QApplication::flushX();
+  emit sig_disconnected();
+  QApplication::flush();
   execute_command(gpppdata.command_on_disconnect());
 
   Requester::rq->removeSecret(AUTH_PAP);
@@ -863,7 +897,7 @@ void KPPPWidget::delayedDisconnect() {
 
 
 void KPPPWidget::helpbutton() {
-  kapp->invokeHelp();
+  KToolInvocation::invokeHelp();
 }
 
 
@@ -871,7 +905,7 @@ void KPPPWidget::quitbutton() {
   if(gpppdata.pppdRunning()) {
     int ok = KMessageBox::warningContinueCancel(this,
 			    i18n("Exiting kPPP will close your PPP Session."),
-			    i18n("Quit kPPP?"), KStdGuiItem::quit());
+			    i18n("Quit kPPP?"), KStandardGuiItem::quit());
     if(ok == KMessageBox::Continue) {
       Requester::rq->killPPPDaemon();
 
@@ -879,9 +913,8 @@ void KPPPWidget::quitbutton() {
       disconnectTimer->stop();
 
       // signal other applications that we are disconnected now
-      kapp->dcopClient()->emitDCOPSignal("KpppIface", "disconnected()", QByteArray());
-
-      QApplication::flushX();
+      emit sig_disconnected();
+      QApplication::flush();
       execute_command(gpppdata.command_on_disconnect());
       removedns();
       Modem::modem->unlockdevice();
@@ -891,7 +924,7 @@ void KPPPWidget::quitbutton() {
       gpppdata.setStoredPassword("");
   }
   gpppdata.save();
-  kapp->quit();
+  qApp->quit();
 }
 
 
@@ -904,7 +937,7 @@ void KPPPWidget::startAccounting() {
   // volume accounting
   stats->totalbytes = 0;
 
-  kdDebug(5002) << "AcctEnabled: " << gpppdata.AcctEnabled() << endl;
+  kDebug(5002) << "AcctEnabled: " << gpppdata.AcctEnabled();
 
   // load the ruleset
   if(!gpppdata.AcctEnabled())
@@ -922,7 +955,7 @@ void KPPPWidget::startAccounting() {
 
   if(!acct->loadRuleSet(gpppdata.accountingFile())) {
     QString s= i18n("Can not load the accounting "
-    		    "ruleset \"%1\".").arg(gpppdata.accountingFile());
+    		    "ruleset \"%1\".", gpppdata.accountingFile());
 
     // starting the messagebox with a timer will prevent us
     // from blocking the calling function ConnectWidget::timerEvent
@@ -1010,10 +1043,12 @@ void KPPPWidget::showNews() {
    */
   #define QUICKHELP_HINT "Hint_QuickHelp"
   if(gpppdata.readNumConfig(GENERAL_GRP, QUICKHELP_HINT, 0) == 0) {
-    QDialog dlg(0, 0, true);
+    KDialog dlg();
     dlg.setCaption(i18n("Recent Changes in KPPP"));
 
-    QVBoxLayout *tl = new QVBoxLayout(&dlg, 10, 10);
+    QVBoxLayout *tl = new QVBoxLayout(&dlg);
+    tl->setSpacing(10);
+    tl->setMargin(10);
     QHBoxLayout *l1 = new QHBoxLayout(10);
     QVBoxLayout *l2 = new QVBoxLayout(10);
     tl->addLayout(l1);
@@ -1036,28 +1071,20 @@ void KPPPWidget::showNews() {
 			      "To test it, right-click somewhere in this text."),
 			 &dlg);
 
-    QCheckBox *cb = new QCheckBox(i18n("Don't show this hint again"), &dlg);
+    QCheckBox *cb = new QCheckBox(i18n("Do not show this hint again"), &dlg);
     cb->setFixedSize(cb->sizeHint());
 
-    KButtonBox *bbox = new KButtonBox(&dlg);
-    bbox->addStretch(1);
-    QPushButton *ok = bbox->addButton(KStdGuiItem::ok());
-    ok->setDefault(true);
-    dlg.connect(ok, SIGNAL(clicked()),
-		&dlg, SLOT(accept()));
-    bbox->addStretch(1);
-    bbox->layout();
+    dlg.setButtons(Ok)
 
     l2->addWidget(l);
     l2->addWidget(cb);
-    tl->addWidget(bbox);
 
     QString tmp = i18n("This is an example of <b>QuickHelp</b>.\n"
 		       "This window will stay open until you\n"
 		       "click a mouse button or a press a key.\n");
 
-    QWhatsThis::add(cb,tmp);
-    QWhatsThis::add(l, tmp);
+    cb->setWhatsThis(tmp);
+    l->setWhatsThis( tmp);
 
     dlg.exec();
     if(cb->isChecked()) {
