@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2007 - 2008 Urs Wolfer <uwolfer @ kde.org>
+** Copyright (C) 2007 - 2009 Urs Wolfer <uwolfer @ kde.org>
 **
 ** This file is part of KDE.
 **
@@ -30,21 +30,10 @@
 #include "bookmarkmanager.h"
 #include "remotedesktopsmodel.h"
 #include "systemtrayicon.h"
+#include "hostpreferences.h"
 
-#ifdef BUILD_RDP
-#include "rdpview.h"
-#endif
-#ifdef BUILD_NX
-#include "nxview.h"
-#endif
-#ifdef BUILD_VNC
-#include "vncview.h"
-#endif
 #ifdef BUILD_ZEROCONF
-#include "zeroconfpage.h"
-#endif
-#ifdef BUILD_TEST
-#include "testview.h"
+#include "zeroconf/zeroconfpage.h"
 #endif
 
 #include <KAction>
@@ -55,10 +44,11 @@
 #include <KEditToolBar>
 #include <KIcon>
 #include <KLocale>
+#include <KMenu>
 #include <KMenuBar>
 #include <KMessageBox>
 #include <KNotifyConfigWidget>
-#include <KProcess>
+#include <KPluginInfo>
 #include <KPushButton>
 #include <KShortcut>
 #include <KShortcutsDialog>
@@ -67,6 +57,7 @@
 #include <KToggleAction>
 #include <KToggleFullScreenAction>
 #include <KUrlNavigator>
+#include <KServiceTypeTrader>
 #include <KStandardDirs>
 
 #include <QClipboard>
@@ -94,20 +85,36 @@ MainWindow::MainWindow(QWidget *parent)
         m_systemTrayIcon(0),
         m_zeroconfPage(0)
 {
+    loadAllPlugins();
+
     setupActions();
 
     setStandardToolBarMenuEnabled(true);
 
     m_tabWidget = new KTabWidget(this);
-    m_tabWidget->setCloseButtonEnabled(true);
+    m_tabWidget->setTabBarHidden(!Settings::showTabBar());
+    m_tabWidget->setTabPosition((KTabWidget::TabPosition) Settings::tabPosition());
+
+#if QT_VERSION <= 0x040500
+    m_tabWidget->setTabsClosable(Settings::tabCloseButton());
+#else
+    m_tabWidget->setCloseButtonEnabled(Settings::tabCloseButton());
+#endif
+
     connect(m_tabWidget, SIGNAL(closeRequest(QWidget *)), SLOT(closeTab(QWidget *)));
 
+    if (Settings::tabMiddleClick())
+        connect(m_tabWidget, SIGNAL(mouseMiddleClick(QWidget *)), SLOT(closeTab(QWidget *)));
+
+    connect(m_tabWidget, SIGNAL(mouseDoubleClick(QWidget *)), SLOT(openTabSettings(QWidget *)));
+    connect(m_tabWidget, SIGNAL(contextMenu(QWidget *, const QPoint &)), SLOT(tabContextMenu(QWidget *, const QPoint &)));
+
     m_tabWidget->setMinimumSize(600, 400);
     setCentralWidget(m_tabWidget);
 
     QDockWidget *remoteDesktopsDockWidget = new QDockWidget(this);
     remoteDesktopsDockWidget->setObjectName("remoteDesktopsDockWidget"); // required for saving position / state
-    remoteDesktopsDockWidget->setWindowTitle(i18n("Remote desktops"));
+    remoteDesktopsDockWidget->setWindowTitle(i18n("Remote Desktops"));
     QFontMetrics fontMetrics(remoteDesktopsDockWidget->font());
     remoteDesktopsDockWidget->setMinimumWidth(fontMetrics.width("vnc://192.168.100.100:6000"));
     actionCollection()->addAction("remote_desktop_dockwidget",
@@ -156,29 +163,14 @@ MainWindow::~MainWindow()
 
 void MainWindow::setupActions()
 {
-    QAction *vncConnectionAction = actionCollection()->addAction("new_vnc_connection");
-    vncConnectionAction->setText(i18n("New VNC Connection..."));
-    vncConnectionAction->setIcon(KIcon("network-connect"));
-    connect(vncConnectionAction, SIGNAL(triggered()), SLOT(newVncConnection()));
-#ifndef BUILD_VNC
-    vncConnectionAction->deleteLater();
-#endif
-
-    QAction *nxConnectionAction = actionCollection()->addAction("new_nx_connection");
-    nxConnectionAction->setText(i18n("New NX Connection..."));
-    nxConnectionAction->setIcon(KIcon("network-connect"));
-    connect(nxConnectionAction, SIGNAL(triggered()), SLOT(newNxConnection()));
-#ifndef BUILD_NX
-    nxConnectionAction->deleteLater();
-#endif
-
-    QAction *rdpConnectionAction = actionCollection()->addAction("new_rdp_connection");
-    rdpConnectionAction->setText(i18n("New RDP Connection..."));
-    rdpConnectionAction->setIcon(KIcon("network-connect"));
-    connect(rdpConnectionAction, SIGNAL(triggered()), SLOT(newRdpConnection()));
-#ifndef BUILD_RDP
-    rdpConnectionAction->deleteLater();
-#endif
+    foreach(RemoteViewFactory *factory, m_remoteViewFactories) {
+        QAction *connectionAction = actionCollection()->addAction("new_" + factory->scheme() + "_connection");
+        connectionAction->setProperty("schemeString", factory->scheme());
+        connectionAction->setProperty("toolTipString", factory->connectToolTipText());
+        connectionAction->setText(factory->connectActionText());
+        connectionAction->setIcon(KIcon("network-connect"));
+        connect(connectionAction, SIGNAL(triggered()), SLOT(newConnectionToolTip()));
+    }
 
     QAction *zeroconfAction = actionCollection()->addAction("zeroconf_page");
     zeroconfAction->setText(i18n("Browse Remote Desktop Services on Local Network..."));
@@ -193,21 +185,17 @@ void MainWindow::setupActions()
     screenshotAction->setIcon(KIcon("ksnapshot"));
     connect(screenshotAction, SIGNAL(triggered()), SLOT(takeScreenshot()));
 
-    QAction *fullscreenAction = actionCollection()->addAction("switch_fullscreen");
-    fullscreenAction->setText(i18n("Switch to Fullscreen Mode"));
-    fullscreenAction->setIcon(KIcon("view-fullscreen"));
-    connect(fullscreenAction, SIGNAL(triggered()), SLOT(switchFullscreen()));
-
     QAction *viewOnlyAction = actionCollection()->addAction("view_only");
     viewOnlyAction->setCheckable(true);
     viewOnlyAction->setText(i18n("View Only"));
     viewOnlyAction->setIcon(KIcon("document-preview"));
     connect(viewOnlyAction, SIGNAL(triggered(bool)), SLOT(viewOnly(bool)));
 
-    QAction *disconnectAction = actionCollection()->addAction("disconnect");
+    KAction *disconnectAction = actionCollection()->addAction("disconnect");
     disconnectAction->setText(i18n("Disconnect"));
-    disconnectAction->setIcon(KIcon("system-log-out"));
-    connect(disconnectAction, SIGNAL(triggered()), SLOT(disconnect()));
+    disconnectAction->setIcon(KIcon("network-disconnect"));
+    disconnectAction->setShortcut(QKeySequence::Close);
+    connect(disconnectAction, SIGNAL(triggered()), SLOT(disconnectHost()));
 
     QAction *showLocalCursorAction = actionCollection()->addAction("show_local_cursor");
     showLocalCursorAction->setCheckable(true);
@@ -218,15 +206,16 @@ void MainWindow::setupActions()
     QAction *grabAllKeysAction = actionCollection()->addAction("grab_all_keys");
     grabAllKeysAction->setCheckable(true);
     grabAllKeysAction->setIcon(KIcon("configure-shortcuts"));
-    grabAllKeysAction->setText(i18n("Grab all possible keys"));
+    grabAllKeysAction->setText(i18n("Grab All Possible Keys"));
     connect(grabAllKeysAction, SIGNAL(triggered(bool)), SLOT(grabAllKeys(bool)));
 
     QAction *scaleAction = actionCollection()->addAction("scale");
     scaleAction->setCheckable(true);
     scaleAction->setIcon(KIcon("zoom-fit-best"));
-    scaleAction->setText(i18n("Scale remote screen to fit window size"));
+    scaleAction->setText(i18n("Scale Remote Screen to Fit Window Size"));
     connect(scaleAction, SIGNAL(triggered(bool)), SLOT(scale(bool)));
 
+    KStandardAction::fullScreen(this, SLOT(switchFullscreen()), 0, actionCollection());
     KStandardAction::quit(this, SLOT(quit()), actionCollection());
     KStandardAction::preferences(this, SLOT(preferences()), actionCollection());
     KStandardAction::configureToolbars(this, SLOT(configureToolbars()), actionCollection());
@@ -236,32 +225,15 @@ void MainWindow::setupActions()
     m_menubarAction = KStandardAction::showMenubar(this, SLOT(showMenubar()), actionCollection());
     m_menubarAction->setChecked(!menuBar()->isHidden());
 
-    QString initialProtocol;
-#ifdef BUILD_RDP
-    initialProtocol = "rdp";
-#endif
-#ifdef BUILD_NX
-    initialProtocol = "nx";
-#endif
-#ifdef BUILD_VNC
-    initialProtocol = "vnc";
-#endif
-
+    const QString initialProtocol(!m_remoteViewFactories.isEmpty() ? (*m_remoteViewFactories.begin())->scheme() : QString());
     m_addressNavigator = new KUrlNavigator(0, KUrl(initialProtocol + "://"), this);
-    m_addressNavigator->setCustomProtocols(QStringList()
-#ifdef BUILD_VNC
-                                           << "vnc"
-#endif
-#ifdef BUILD_NX
-                                           << "nx"
-#endif
-#ifdef BUILD_RDP
-                                           << "rdp"
-#endif
-#ifdef BUILD_TEST
-                                           << "test"
-#endif
-                                          );
+
+    QStringList schemes;
+    foreach(RemoteViewFactory *factory, m_remoteViewFactories) {
+        schemes << factory->scheme();
+    }
+    m_addressNavigator->setCustomProtocols(schemes);
+
     m_addressNavigator->setUrlEditable(Settings::normalUrlInputLine());
     connect(m_addressNavigator, SIGNAL(returnPressed()), SLOT(newConnection()));
 
@@ -288,6 +260,57 @@ void MainWindow::setupActions()
     connect(m_bookmarkManager, SIGNAL(openUrl(KUrl)), SLOT(newConnection(KUrl)));
 }
 
+void MainWindow::loadAllPlugins()
+{
+    const KService::List offers = KServiceTypeTrader::self()->query("KRDC/Plugin");
+
+    KConfigGroup conf(KGlobal::config(), "Plugins");
+
+    for (int i = 0; i < offers.size(); i++) {
+        KService::Ptr offer = offers[i];
+
+        RemoteViewFactory *remoteView;
+
+        KPluginInfo description(offer);
+        description.load(conf);
+
+        const bool selected = description.isPluginEnabled();
+
+        if (selected) {
+            if ((remoteView = createPluginFromService(offer)) != 0) {
+                kDebug(5010) << "### Plugin " + description.name() + " found ###";
+                kDebug(5010) << "# Version:" << description.version();
+                kDebug(5010) << "# Description:" << description.comment();
+                kDebug(5010) << "# Author:" << description.author();
+                const int sorting = offer->property("X-KDE-KRDC-Sorting").toInt();
+                kDebug(5010) << "# Sorting:" << sorting;
+
+                m_remoteViewFactories.insert(sorting, remoteView);
+            } else {
+                kDebug(5010) << "Error loading KRDC plugin (" << (offers[i])->library() << ')';
+            }
+        } else {
+            kDebug(5010) << "# Plugin " + description.name() + " found, however it's not activated, skipping...";
+            continue;
+        }
+    }
+}
+
+RemoteViewFactory *MainWindow::createPluginFromService(const KService::Ptr &service)
+{
+    //try to load the specified library
+    KPluginFactory *factory = KPluginLoader(service->library()).factory();
+
+    if (!factory) {
+        kError(5010) << "KPluginFactory could not load the plugin:" << service->library();
+        return 0;
+    }
+
+    RemoteViewFactory *plugin = factory->create<RemoteViewFactory>();
+
+    return plugin;
+}
+
 void MainWindow::restoreOpenSessions()
 {
     const QStringList list = Settings::openSessions();
@@ -318,34 +341,18 @@ void MainWindow::newConnection(const KUrl &newUrl, bool switchFullscreenWhenConn
     RemoteView *view = 0;
     KConfigGroup configGroup = Settings::self()->config()->group("hostpreferences").group(url.prettyUrl(KUrl::RemoveTrailingSlash));
 
-    if (url.scheme().compare("vnc", Qt::CaseInsensitive) == 0) {
-#ifdef BUILD_VNC
-        view = new VncView(this, url, configGroup);
-#endif
-    } else if (url.scheme().compare("nx", Qt::CaseInsensitive) == 0) {
-#ifdef BUILD_NX
-        view = new NxView(this, url, configGroup);
-#endif
-    } else if (url.scheme().compare("rdp", Qt::CaseInsensitive) == 0) {
-#ifdef BUILD_RDP
-        view = new RdpView(this, url, configGroup);
-#endif
-    } else if (url.scheme().compare("test", Qt::CaseInsensitive) == 0) {
-#ifdef BUILD_TEST
-        view = new TestView(this, url, configGroup);
-#endif
-    } else
-    {
-        KMessageBox::error(this,
-                           i18n("The entered address cannot be handled."),
-                           i18n("Unusable URL"));
-        return;
+    foreach(RemoteViewFactory *factory, m_remoteViewFactories) {
+        if (factory->supportsUrl(url)) {
+            view = factory->createView(this, url, configGroup);
+            kDebug(5010) << "Found plugin to handle url (" + url.url() + "): " + view->metaObject()->className();
+            break;
+        }
     }
 
     if (!view) {
-        KMessageBox::error(this, i18n("Support for %1:// has not been enabled during build.",
-                    url.scheme().toLower()),
-                i18n("Unusable URL"));
+        KMessageBox::error(this,
+                           i18n("The entered address cannot be handled."),
+                           i18n("Unusable URL"));
         return;
     }
     
@@ -365,6 +372,7 @@ void MainWindow::newConnection(const KUrl &newUrl, bool switchFullscreenWhenConn
 
     connect(view, SIGNAL(framebufferSizeChanged(int, int)), this, SLOT(resizeTabWidget(int, int)));
     connect(view, SIGNAL(statusChanged(RemoteView::RemoteStatus)), this, SLOT(statusChanged(RemoteView::RemoteStatus)));
+    connect(view, SIGNAL(disconnected()), this, SLOT(disconnectHost()));
 
     m_remoteViewList.append(view);
 
@@ -392,7 +400,7 @@ void MainWindow::newConnection(const KUrl &newUrl, bool switchFullscreenWhenConn
 
 void MainWindow::openFromDockWidget(const QModelIndex &index)
 {
-    const QString data = index.data(Qt::UserRole).toString();
+    const QString data = index.data(10001).toString();
     if (!data.isEmpty()) {
         const KUrl url(data);
         // first check if url has already been opened; in case show the tab
@@ -524,17 +532,12 @@ void MainWindow::switchFullscreen()
         m_tabWidget->removeTab(m_tabWidget->currentIndex());
         m_tabWidget->setCurrentIndex(currentTab);
 
-        resizeTabWidget(view->sizeHint().width(), view->sizeHint().height());
-
         if (m_toolBar) {
             m_toolBar->hideAndDestroy();
             m_toolBar->deleteLater();
             m_toolBar = 0;
         }
 
-        actionCollection()->action("switch_fullscreen")->setIcon(KIcon("view-fullscreen"));
-        actionCollection()->action("switch_fullscreen")->setText(i18n("Switch to Fullscreen Mode"));
-
         m_fullscreenWindow->deleteLater();
 
         m_fullscreenWindow = 0;
@@ -585,20 +588,31 @@ QScrollArea *MainWindow::createScrollArea(QWidget *parent, RemoteView *remoteVie
     return scrollArea;
 }
 
-void MainWindow::disconnect()
+void MainWindow::disconnectHost()
 {
     kDebug(5010);
 
-    if (m_fullscreenWindow) { // first close fullscreen view
-        switchFullscreen();
-    }
+    RemoteView *view = qobject_cast<RemoteView*>(QObject::sender());
 
-    QWidget *tmp = m_tabWidget->currentWidget();
-    m_remoteViewList.removeAt(m_currentRemoteView);
-    m_tabWidget->removeTab(m_tabWidget->currentIndex());
-    tmp->deleteLater();
-    
-    saveHostPrefs();
+    if (view) {
+        QWidget *tmp = (QWidget*) view->parent()->parent();
+        m_remoteViewList.removeOne(view);
+        m_tabWidget->removePage(tmp);
+        tmp->deleteLater();
+
+        saveHostPrefs(view);
+    } else {
+        if (m_fullscreenWindow) { // first close fullscreen view
+            switchFullscreen();
+        }
+
+        QWidget *tmp = m_tabWidget->currentWidget();
+        m_remoteViewList.removeAt(m_currentRemoteView);
+        m_tabWidget->removeTab(m_tabWidget->currentIndex());
+        tmp->deleteLater();
+
+        saveHostPrefs();
+    }
 }
 
 void MainWindow::closeTab(QWidget *widget)
@@ -608,8 +622,12 @@ void MainWindow::closeTab(QWidget *widget)
     kDebug(5010) << index;
 
     if (m_showStartPage && index == 0) {
-        KMessageBox::information(this, i18n("The start page cannot be closed. "
-                                            "If you want to disable it, you can do so in the settings."));
+        KMessageBox::information(this, i18n("You can enable the start page in the settings again."));
+
+        Settings::setShowStartPage(false);
+        m_tabWidget->removeTab(0);
+        m_showStartPage = false;
+	updateActionStatus();
         return;
     }
 
@@ -634,13 +652,72 @@ void MainWindow::closeTab(QWidget *widget)
     widget->deleteLater();
 }
 
+void MainWindow::openTabSettings(QWidget *widget)
+{
+    RemoteViewScrollArea *scrollArea = qobject_cast<RemoteViewScrollArea*>(widget);
+    if (!scrollArea) return;
+    RemoteView *view = qobject_cast<RemoteView*>(scrollArea->widget());
+    if (!view) return;
+
+    const QString url = view->url().url();
+    kDebug(5010) << url;
+
+    HostPreferences *prefs = 0;
+
+    foreach(RemoteViewFactory *factory, remoteViewFactoriesList()) {
+        if (factory->supportsUrl(url)) {
+            prefs = factory->createHostPreferences(Settings::self()->config()->group("hostpreferences").group(url), this);
+            if (prefs) {
+                kDebug(5010) << "Found plugin to handle url (" + url + "): " + prefs->metaObject()->className();
+            } else {
+                kDebug(5010) << "Found plugin to handle url (" + url + "), but plugin does not provide preferences";
+            }
+        }
+    }
+
+    if (prefs) {
+        prefs->setShownWhileConnected(true);
+        prefs->showDialog();
+        delete prefs;
+    } else {
+        KMessageBox::error(this,
+                           i18n("The selected host cannot be handled."),
+                           i18n("Unusable URL"));
+    }
+}
+
+void MainWindow::tabContextMenu(QWidget *widget, const QPoint &point)
+{
+    RemoteViewScrollArea *scrollArea = qobject_cast<RemoteViewScrollArea*>(widget);
+    if (!scrollArea) return;
+    RemoteView *view = qobject_cast<RemoteView*>(scrollArea->widget());
+    if (!view) return;
+
+    const QString url = view->url().url();
+    kDebug(5010) << url;
+
+    KMenu *menu = new KMenu(this);
+    menu->addTitle(url);
+    QAction *bookmarkAction = menu->addAction(KIcon("bookmark-new"), i18n("Add Bookmark"));
+    QAction *closeAction = menu->addAction(KIcon("tab-close"), i18n("Close Tab"));
+    QAction *selectedAction = menu->exec(point);
+    if (selectedAction) {
+        if (selectedAction == closeAction) {
+            closeTab(widget);
+        } else if (selectedAction == bookmarkAction) {
+            m_bookmarkManager->addManualBookmark(url, url);
+        }
+    }
+    menu->deleteLater();
+}
+
 void MainWindow::showLocalCursor(bool showLocalCursor)
 {
     kDebug(5010) << showLocalCursor;
 
     RemoteView* view = m_remoteViewList.at(m_currentRemoteView);
     view->showDotCursor(showLocalCursor ? RemoteView::CursorOn : RemoteView::CursorOff);
-    view->hostPreferences()->setViewOnly(showLocalCursor);
+    view->hostPreferences()->setShowLocalCursor(showLocalCursor);
     saveHostPrefs();
 }
 
@@ -683,9 +760,6 @@ void MainWindow::showRemoteViewToolbar()
     kDebug(5010);
 
     if (!m_toolBar) {
-        actionCollection()->action("switch_fullscreen")->setIcon(KIcon("view-restore"));
-        actionCollection()->action("switch_fullscreen")->setText(i18n("Switch to Window Mode"));
-
         m_toolBar = new FloatingToolBar(m_fullscreenWindow, m_fullscreenWindow);
         m_toolBar->winId(); // force it to be a native widget (prevents problem with QX11EmbedContainer)
         m_toolBar->setSide(FloatingToolBar::Top);
@@ -708,10 +782,10 @@ void MainWindow::showRemoteViewToolbar()
         m_toolBar->addWidget(sessionComboBox);
 #endif
 
-        m_toolBar->addAction(actionCollection()->action("switch_fullscreen"));
+        m_toolBar->addAction(actionCollection()->action("fullscreen"));
 
         QAction *minimizeAction = new QAction(m_toolBar);
-        minimizeAction->setIcon(KIcon("window-suppressed"));
+        minimizeAction->setIcon(KIcon("go-down"));
         minimizeAction->setText(i18n("Minimize Fullscreen Window"));
         connect(minimizeAction, SIGNAL(triggered()), m_fullscreenWindow, SLOT(showMinimized()));
         m_toolBar->addAction(minimizeAction);
@@ -758,7 +832,7 @@ void MainWindow::updateActionStatus()
 
     RemoteView* view = m_currentRemoteView >= 0 ? m_remoteViewList.at(m_currentRemoteView) : NULL;
     
-    actionCollection()->action("switch_fullscreen")->setEnabled(enabled);
+    actionCollection()->action("fullscreen")->setEnabled(enabled);
     actionCollection()->action("take_screenshot")->setEnabled(enabled);
     actionCollection()->action("disconnect")->setEnabled(enabled);
 
@@ -807,6 +881,17 @@ void MainWindow::updateConfiguration()
 {
     m_addressNavigator->setUrlEditable(Settings::normalUrlInputLine());
 
+    m_tabWidget->setTabBarHidden(!Settings::showTabBar());
+    m_tabWidget->setTabPosition((KTabWidget::TabPosition) Settings::tabPosition());
+#if QT_VERSION <= 0x040500
+    m_tabWidget->setTabsClosable(Settings::tabCloseButton());
+#else
+    m_tabWidget->setCloseButtonEnabled(Settings::tabCloseButton());
+#endif
+    disconnect(m_tabWidget, SIGNAL(mouseMiddleClick(QWidget *)), this, SLOT(closeTab(QWidget *))); // just be sure it is not connected twice
+    if (Settings::tabMiddleClick())
+        connect(m_tabWidget, SIGNAL(mouseMiddleClick(QWidget *)), SLOT(closeTab(QWidget *)));
+
     if (Settings::systemTrayIcon() && !m_systemTrayIcon) {
         m_systemTrayIcon = new SystemTrayIcon(this);
         m_systemTrayIcon->setVisible(true);
@@ -914,10 +999,12 @@ void MainWindow::saveProperties(KConfigGroup &group)
     saveHostPrefs();
 }
 
-void MainWindow::saveHostPrefs()
+void MainWindow::saveHostPrefs(RemoteView* view)
 {
     // Save default window size for currently active view
-    RemoteView* view = m_currentRemoteView >= 0 ? m_remoteViewList.at(m_currentRemoteView) : NULL;
+    if (!view)
+        view = m_currentRemoteView >= 0 ? m_remoteViewList.at(m_currentRemoteView) : NULL;
+
     if (view)
         saveWindowSize(view->hostPreferences()->configGroup());
     
@@ -961,34 +1048,18 @@ void MainWindow::createStartPage()
     headerLayout->setMargin(20);
     headerLayout->addWidget(headerLabel, 1, Qt::AlignTop);
     headerLayout->addWidget(headerIconLabel);
+    startLayout->addLayout(headerLayout);
 
-    KPushButton *vncConnectButton = new KPushButton(this);
-    vncConnectButton->setStyleSheet("KPushButton { padding: 12px; margin: 10px; }");
-    vncConnectButton->setIcon(KIcon(actionCollection()->action("new_vnc_connection")->icon()));
-    vncConnectButton->setText(i18n("Connect to a VNC Remote Desktop"));
-    connect(vncConnectButton, SIGNAL(clicked()), SLOT(newVncConnection()));
-#ifndef BUILD_VNC
-    vncConnectButton->setVisible(false);
-#endif
-
-    KPushButton *nxConnectButton = new KPushButton(this);
-    nxConnectButton->setStyleSheet("KPushButton { padding: 12px; margin: 10px; }");
-    nxConnectButton->setIcon(KIcon(actionCollection()->action("new_nx_connection")->icon()));
-    nxConnectButton->setText(i18n("Connect to a NX Remote Desktop"));
-    connect(nxConnectButton, SIGNAL(clicked()), SLOT(newNxConnection()));
-#ifndef BUILD_NX
-    nxConnectButton->setVisible(false);
-#endif
-
-    rdpConnectButton = new KPushButton(this);
-    rdpConnectButton->setStyleSheet("KPushButton { padding: 12px; margin: 10px; }");
-    rdpConnectButton->setIcon(KIcon(actionCollection()->action("new_rdp_connection")->icon()));
-    rdpConnectButton->setText(i18n("Connect to a Windows Remote Desktop (RDP)"));
-    connect(rdpConnectButton, SIGNAL(clicked()), SLOT(newRdpConnection()));
-    QMetaObject::invokeMethod(this, "checkRdektopAvailability");
-#ifndef BUILD_RDP
-    rdpConnectButton->setVisible(false);
-#endif
+    foreach(RemoteViewFactory *factory, m_remoteViewFactories) {
+        KPushButton *connectButton = new KPushButton(this);
+        connectButton->setProperty("schemeString", factory->scheme());
+        connectButton->setProperty("toolTipString", factory->connectToolTipText());
+        connectButton->setStyleSheet("KPushButton { padding: 12px; margin: 10px; }");
+        connectButton->setIcon(KIcon(actionCollection()->action("new_" + factory->scheme() + "_connection")->icon()));
+        connectButton->setText(factory->connectButtonText());
+        connect(connectButton, SIGNAL(clicked()), SLOT(newConnectionToolTip()));
+        startLayout->addWidget(connectButton);
+    }
 
     KPushButton *zeroconfButton = new KPushButton(this);
     zeroconfButton->setStyleSheet("KPushButton { padding: 12px; margin: 10px; }");
@@ -999,47 +1070,24 @@ void MainWindow::createStartPage()
     zeroconfButton->setVisible(false);
 #endif
 
-    startLayout->addLayout(headerLayout);
-    startLayout->addWidget(vncConnectButton);
-    startLayout->addWidget(nxConnectButton);
-    startLayout->addWidget(rdpConnectButton);
     startLayout->addWidget(zeroconfButton);
     startLayout->addStretch();
 
     m_tabWidget->insertTab(0, startWidget, KIcon("krdc"), i18n("Start Page"));
 }
 
-void MainWindow::newVncConnection()
+void MainWindow::newConnectionToolTip()
 {
-    m_addressNavigator->setUrl(KUrl("vnc://"));
+    QObject *senderObject = qobject_cast<QObject*>(sender());
+    const QString toolTip(senderObject->property("toolTipString").toString());
+    const QString scheme(senderObject->property("schemeString").toString());
+
+    m_addressNavigator->setUrl(KUrl(scheme + "://"));
     m_addressNavigator->setFocus();
 
     QToolTip::showText(m_addressNavigator->pos() + pos() + QPoint(m_addressNavigator->width(),
-                                                                  m_addressNavigator->height() + 20),
-                       i18n("<html>Enter the address here.<br />"
-                            "<i>Example: vncserver:1 (host:port / screen)</i></html>"), this);
-}
-
-void MainWindow::newNxConnection()
-{
-    m_addressNavigator->setUrl(KUrl("nx://"));
-    m_addressNavigator->setFocus();
-
-    QToolTip::showText(m_addressNavigator->pos() + pos() + QPoint(m_addressNavigator->width(),
-                                                                  m_addressNavigator->height() + 20),
-                       i18n("<html>Enter the address here.<br />"
-                            "<i>Example: nxserver (host)</i></html>"), this);
-}
-
-void MainWindow::newRdpConnection()
-{
-    m_addressNavigator->setUrl(KUrl("rdp://"));
-    m_addressNavigator->setFocus();
-
-    QToolTip::showText(m_addressNavigator->pos() + pos() + QPoint(m_addressNavigator->width(),
-                                                                  m_addressNavigator->height() + 20),
-                       i18n("<html>Enter the address here. Port is optional.<br />"
-                            "<i>Example: rdpserver:3389 (host:port)</i></html>"), this);
+                                                                  m_addressNavigator->height() / 2),
+                       toolTip, this);
 }
 
 void MainWindow::createZeroconfPage()
@@ -1051,7 +1099,7 @@ void MainWindow::createZeroconfPage()
     m_zeroconfPage = new ZeroconfPage(this);
     connect(m_zeroconfPage, SIGNAL(newConnection(const KUrl, bool)), this, SLOT(newConnection(const KUrl, bool)));
     connect(m_zeroconfPage, SIGNAL(closeZeroconfPage()), this, SLOT(closeZeroconfPage()));
-    int zeroconfTabIndex = m_tabWidget->insertTab(m_showStartPage ? 1 : 0, m_zeroconfPage, KIcon("krdc"), i18n("Browse Local Network"));
+    const int zeroconfTabIndex = m_tabWidget->insertTab(m_showStartPage ? 1 : 0, m_zeroconfPage, KIcon("krdc"), i18n("Browse Local Network"));
     m_tabWidget->setCurrentIndex(zeroconfTabIndex);
 #endif
 }
@@ -1059,27 +1107,23 @@ void MainWindow::createZeroconfPage()
 void MainWindow::closeZeroconfPage()
 {
 #ifdef BUILD_ZEROCONF
-    int index = m_tabWidget->indexOf(m_zeroconfPage);
+    const int index = m_tabWidget->indexOf(m_zeroconfPage);
     m_tabWidget->removeTab(index);
     m_zeroconfPage->deleteLater();
     m_zeroconfPage = 0;
 #endif
 }
 
-void MainWindow::checkRdektopAvailability()
-{
-    if (KStandardDirs::findExe("rdesktop").isEmpty()) {
-        rdpConnectButton->setEnabled(false);
-        rdpConnectButton->setText(rdpConnectButton->text() + '\n' + 
-                                  i18n("\"rdesktop\" cannot be found on your system; make sure it is properly installed."));
-    }
-}
-
 QList<RemoteView *> MainWindow::remoteViewList() const
 {
     return m_remoteViewList;
 }
 
+QList<RemoteViewFactory *> MainWindow::remoteViewFactoriesList() const
+{
+    return m_remoteViewFactories.values();
+}
+
 int MainWindow::currentRemoteView() const
 {
     return m_currentRemoteView;
