@@ -29,7 +29,7 @@
 
 #include <QDesktopWidget>
 
-static QStringList keymaps = (QStringList()
+static const QStringList keymaps = (QStringList()
     << "ar"
     << "cs"
     << "da"
@@ -73,7 +73,7 @@ static const int defaultKeymap = 7; // en-us
 
 inline int keymap2int(const QString &keymap)
 {
-    int index = keymaps.lastIndexOf(keymap);
+    const int index = keymaps.lastIndexOf(keymap);
     return (index == -1) ? defaultKeymap : index;
 }
 
@@ -85,40 +85,21 @@ inline QString int2keymap(int layout)
         return keymaps.at(defaultKeymap);
 }
 
-RdpHostPreferences::RdpHostPreferences(const QString &url, bool forceShow, QObject *parent)
-  : HostPreferences(url, parent),
-    m_height(600),
-    m_width(800),
-    m_colorDepth(0),
-    m_keyboardLayout("en-us"),
-    m_sound(0),
-    m_extraOptions(QString())
+RdpHostPreferences::RdpHostPreferences(KConfigGroup configGroup, QObject *parent)
+  : HostPreferences(configGroup, parent)
 {
-    if (hostConfigured()) {
-        if (showConfigAgain() || forceShow) {
-            kDebug(5012) << "Show config dialog again";
-            showDialog();
-        } else
-            return; // no changes, no need to save
-    } else {
-        kDebug(5012) << "No config found, create new";
-        if (Settings::showPreferencesForNewConnections())
-            showDialog();
-    }
-
-    saveConfig();
 }
 
 RdpHostPreferences::~RdpHostPreferences()
 {
 }
 
-void RdpHostPreferences::showDialog()
+QWidget* RdpHostPreferences::createProtocolSpecificConfigPage()
 {
     QWidget *rdpPage = new QWidget();
     rdpUi.setupUi(rdpPage);
 
-    KDialog *dialog = createDialog(rdpPage);
+    rdpUi.loginGroupBox->setVisible(false);
 
     rdpUi.kcfg_Height->setValue(height());
     rdpUi.kcfg_Width->setValue(width());
@@ -129,20 +110,11 @@ void RdpHostPreferences::showDialog()
 
     connect(rdpUi.resolutionComboBox, SIGNAL(currentIndexChanged(int)), SLOT(updateWidthHeight(int)));
 
-    QString resolutionString = QString::number(width()) + 'x' + QString::number(height());
-    int resolutionIndex = rdpUi.resolutionComboBox->findText(resolutionString, Qt::MatchContains);
+    const QString resolutionString = QString::number(width()) + 'x' + QString::number(height());
+    const int resolutionIndex = rdpUi.resolutionComboBox->findText(resolutionString, Qt::MatchContains);
     rdpUi.resolutionComboBox->setCurrentIndex((resolutionIndex == -1) ? rdpUi.resolutionComboBox->count() - 1 : resolutionIndex);
 
-    if (dialog->exec() == KDialog::Accepted) {
-        kDebug(5012) << "RdpHostPreferences config dialog accepted";
-
-        setHeight(rdpUi.kcfg_Height->value());
-        setWidth(rdpUi.kcfg_Width->value());
-        setColorDepth(rdpUi.kcfg_ColorDepth->currentIndex());
-        setKeyboardLayout(int2keymap(rdpUi.kcfg_KeyboardLayout->currentIndex()));
-        setSound(rdpUi.kcfg_Sound->currentIndex());
-        setExtraOptions(rdpUi.kcfg_ExtraOptions->text());
-    }
+    return rdpPage;
 }
 
 void RdpHostPreferences::updateWidthHeight(int index)
@@ -180,7 +152,7 @@ void RdpHostPreferences::updateWidthHeight(int index)
         break;
     }
 
-    bool enabled = (index == 6) ? true : false;
+    const bool enabled = (index == 6) ? true : false;
 
     rdpUi.kcfg_Height->setEnabled(enabled);
     rdpUi.kcfg_Width->setEnabled(enabled);
@@ -188,117 +160,92 @@ void RdpHostPreferences::updateWidthHeight(int index)
     rdpUi.widthLabel->setEnabled(enabled);
 }
 
-void RdpHostPreferences::readProtocolSpecificConfig()
+void RdpHostPreferences::acceptConfig()
 {
-    kDebug(5012) << "RdpHostPreferences::readProtocolSpecificConfig";
+    HostPreferences::acceptConfig();
 
-    if (m_element.firstChildElement("height") != QDomElement()) // not configured yet
-        setHeight(m_element.firstChildElement("height").text().toInt());
-    else
-        setHeight(Settings::height()); // get the proctocol default
-
-    if (m_element.firstChildElement("width") != QDomElement())
-        setWidth(m_element.firstChildElement("width").text().toInt());
-    else
-        setWidth(Settings::width());
-
-    if (m_element.firstChildElement("colorDepth") != QDomElement())
-        setColorDepth(m_element.firstChildElement("colorDepth").text().toInt());
-    else
-        setColorDepth(Settings::colorDepth());
-
-    if (m_element.firstChildElement("keyboardLayout") != QDomElement())
-        setKeyboardLayout(int2keymap(m_element.firstChildElement("keyboardLayout").text().toInt()));
-    else
-        setKeyboardLayout(int2keymap(Settings::keyboardLayout()));
-
-    if (m_element.firstChildElement("sound") != QDomElement())
-        setSound(m_element.firstChildElement("sound").text().toInt());
-    else
-        setSound(Settings::sound());
-
-    if (m_element.firstChildElement("extraOptions") != QDomElement())
-        setExtraOptions(m_element.firstChildElement("extraOptions").text());
-    else
-        setExtraOptions(Settings::extraOptions());
-}
-
-void RdpHostPreferences::saveProtocolSpecificConfig()
-{
-    kDebug(5012) << "RdpHostPreferences::saveProtocolSpecificConfig";
-
-    updateElement("height", QString::number(height()));
-    updateElement("width", QString::number(width()));
-    updateElement("colorDepth", QString::number(colorDepth()));
-    updateElement("keyboardLayout", QString::number(keymap2int(keyboardLayout())));
-    updateElement("sound", QString::number(sound()));
-    updateElement("extraOptions", extraOptions());
+    setHeight(rdpUi.kcfg_Height->value());
+    setWidth(rdpUi.kcfg_Width->value());
+    setColorDepth(rdpUi.kcfg_ColorDepth->currentIndex());
+    setKeyboardLayout(int2keymap(rdpUi.kcfg_KeyboardLayout->currentIndex()));
+    setSound(rdpUi.kcfg_Sound->currentIndex());
+    setExtraOptions(rdpUi.kcfg_ExtraOptions->text());
 }
 
 void RdpHostPreferences::setHeight(int height)
 {
     if (height >= 0)
-        m_height = height;
+        m_configGroup.writeEntry("height", height);
 }
 
-int RdpHostPreferences::height()
+int RdpHostPreferences::height() const
 {
-    return m_height;
+    return m_configGroup.readEntry("height", Settings::height());
 }
 
 void RdpHostPreferences::setWidth(int width)
 {
     if (width >= 0)
-        m_width = width;
+        m_configGroup.writeEntry("width", width);
 }
 
-int RdpHostPreferences::width()
+int RdpHostPreferences::width() const
 {
-    return m_width;
+    return m_configGroup.readEntry("width", Settings::width());
 }
 
 void RdpHostPreferences::setColorDepth(int colorDepth)
 {
     if (colorDepth >= 0)
-        m_colorDepth = colorDepth;
+        m_configGroup.writeEntry("colorDepth", colorDepth);
 }
 
-int RdpHostPreferences::colorDepth()
+int RdpHostPreferences::colorDepth() const
 {
-    return m_colorDepth;
+    return m_configGroup.readEntry("colorDepth", Settings::colorDepth());
 }
 
 void RdpHostPreferences::setKeyboardLayout(const QString &keyboardLayout)
 {
     if (!keyboardLayout.isNull())
-        m_keyboardLayout = keyboardLayout;
+        m_configGroup.writeEntry("keyboardLayout", keymap2int(keyboardLayout));
 }
 
 QString RdpHostPreferences::keyboardLayout() const
 {
-    return m_keyboardLayout;
+    return int2keymap(m_configGroup.readEntry("keyboardLayout", Settings::keyboardLayout()));
 }
 
 void RdpHostPreferences::setSound(int sound)
 {
     if (sound >= 0)
-        m_sound = sound;
+        m_configGroup.writeEntry("sound", sound);
 }
 
 int RdpHostPreferences::sound() const
 {
-    return m_sound;
+    return m_configGroup.readEntry("sound", Settings::sound());
+}
+
+void RdpHostPreferences::setConsole(bool console)
+{
+    m_configGroup.writeEntry("console", console);
+}
+
+bool RdpHostPreferences::console() const
+{
+    return m_configGroup.readEntry("console", Settings::console());
 }
 
 void RdpHostPreferences::setExtraOptions(const QString &extraOptions)
 {
     if (!extraOptions.isNull())
-        m_extraOptions = extraOptions;
+        m_configGroup.writeEntry("extraOptions", extraOptions);
 }
 
 QString RdpHostPreferences::extraOptions() const
 {
-    return m_extraOptions;
+    return m_configGroup.readEntry("extraOptions", Settings::extraOptions());
 }
 
 #include "rdphostpreferences.moc"
